@@ -8,7 +8,7 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines the :class:`GpsMap` Component Interface class and the :class:`Map` class.
+	Defines the :class:`GpsMap` Component Interface class and the :class:`Map` class.
 
 **Others:**
 
@@ -45,7 +45,7 @@ from umbra.globals.constants import Constants
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
@@ -62,18 +62,22 @@ COMPONENT_FILE = os.path.join(os.path.dirname(__file__), "ui", "Gps_Map.ui")
 #**********************************************************************************************************************
 class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	"""
-	| This class is the :mod:`sibl_gui.components.addons.gpsMap.gpsMap` Component Interface class.
+	| Defines the :mod:`sibl_gui.components.addons.gpsMap.gpsMap` Component Interface class.
 	| It displays the GPS map inside a `QDockWidget <http://doc.qt.nokia.com/qdockwidget.html>`_ window.
 	"""
 
 	def __init__(self, parent=None, name=None, *args, **kwargs):
 		"""
-		This method initializes the class.
+		Initializes the class.
 
-		:param parent: Object parent. ( QObject )
-		:param name: Component name. ( String )
-		:param \*args: Arguments. ( \* )
-		:param \*\*kwargs: Keywords arguments. ( \*\* )
+		:param parent: Object parent.
+		:type parent: QObject
+		:param name: Component name.
+		:type name: unicode
+		:param \*args: Arguments.
+		:type \*args: \*
+		:param \*\*kwargs: Keywords arguments.
+		:type \*\*kwargs: \*\*
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
@@ -103,9 +107,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@property
 	def uiResourcesDirectory(self):
 		"""
-		This method is the property for **self.__uiResourcesDirectory** attribute.
+		Property for **self.__uiResourcesDirectory** attribute.
 
-		:return: self.__uiResourcesDirectory. ( String )
+		:return: self.__uiResourcesDirectory.
+		:rtype: unicode
 		"""
 
 		return self.__uiResourcesDirectory
@@ -114,9 +119,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiResourcesDirectory(self, value):
 		"""
-		This method is the setter method for **self.__uiResourcesDirectory** attribute.
+		Setter for **self.__uiResourcesDirectory** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -126,7 +132,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiResourcesDirectory(self):
 		"""
-		This method is the deleter method for **self.__uiResourcesDirectory** attribute.
+		Deleter for **self.__uiResourcesDirectory** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -135,9 +141,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@property
 	def uiZoomInImage(self):
 		"""
-		This method is the property for **self.__uiZoomInImage** attribute.
+		Property for **self.__uiZoomInImage** attribute.
 
-		:return: self.__uiZoomInImage. ( String )
+		:return: self.__uiZoomInImage.
+		:rtype: unicode
 		"""
 
 		return self.__uiZoomInImage
@@ -146,9 +153,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiZoomInImage(self, value):
 		"""
-		This method is the setter method for **self.__uiZoomInImage** attribute.
+		Setter for **self.__uiZoomInImage** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -158,7 +166,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiZoomInImage(self):
 		"""
-		This method is the deleter method for **self.__uiZoomInImage** attribute.
+		Deleter for **self.__uiZoomInImage** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -167,9 +175,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@property
 	def uiZoomOutImage(self):
 		"""
-		This method is the property for **self.__uiZoomOutImage** attribute.
+		Property for **self.__uiZoomOutImage** attribute.
 
-		:return: self.__uiZoomOutImage. ( String )
+		:return: self.__uiZoomOutImage.
+		:rtype: unicode
 		"""
 
 		return self.__uiZoomOutImage
@@ -178,9 +187,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiZoomOutImage(self, value):
 		"""
-		This method is the setter method for **self.__uiZoomOutImage** attribute.
+		Setter for **self.__uiZoomOutImage** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -190,7 +200,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiZoomOutImage(self):
 		"""
-		This method is the deleter method for **self.__uiZoomOutImage** attribute.
+		Deleter for **self.__uiZoomOutImage** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -199,9 +209,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@property
 	def gpsMapHtmlFile(self):
 		"""
-		This method is the property for **self.__gpsMapHtmlFile** attribute.
+		Property for **self.__gpsMapHtmlFile** attribute.
 
-		:return: self.__gpsMapHtmlFile. ( String )
+		:return: self.__gpsMapHtmlFile.
+		:rtype: unicode
 		"""
 
 		return self.__gpsMapHtmlFile
@@ -210,9 +221,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def gpsMapHtmlFile(self, value):
 		"""
-		This method is the setter method for **self.__gpsMapHtmlFile** attribute.
+		Setter for **self.__gpsMapHtmlFile** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -222,7 +234,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def gpsMapHtmlFile(self):
 		"""
-		This method is the deleter method for **self.__gpsMapHtmlFile** attribute.
+		Deleter for **self.__gpsMapHtmlFile** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -231,7 +243,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@property
 	def gpsMapBaseSize(self):
 		"""
-		This method is the property for **self.__gpsMapBaseSize** attribute.
+		Property for **self.__gpsMapBaseSize** attribute.
 
 		:return: self.__gpsMapBaseSize. ( QSize() )
 		"""
@@ -242,7 +254,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def gpsMapBaseSize(self, value):
 		"""
-		This method is the setter method for **self.__gpsMapBaseSize** attribute.
+		Setter for **self.__gpsMapBaseSize** attribute.
 
 		:param value: Attribute value. ( QSize() )
 		"""
@@ -254,7 +266,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def gpsMapBaseSize(self):
 		"""
-		This method is the deleter method for **self.__gpsMapBaseSize** attribute.
+		Deleter for **self.__gpsMapBaseSize** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -263,9 +275,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@property
 	def dockArea(self):
 		"""
-		This method is the property for **self.__dockArea** attribute.
+		Property for **self.__dockArea** attribute.
 
-		:return: self.__dockArea. ( Integer )
+		:return: self.__dockArea.
+		:rtype: int
 		"""
 
 		return self.__dockArea
@@ -274,9 +287,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def dockArea(self, value):
 		"""
-		This method is the setter method for **self.__dockArea** attribute.
+		Setter for **self.__dockArea** attribute.
 
-		:param value: Attribute value. ( Integer )
+		:param value: Attribute value.
+		:type value: int
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -286,7 +300,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def dockArea(self):
 		"""
-		This method is the deleter method for **self.__dockArea** attribute.
+		Deleter for **self.__dockArea** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -295,9 +309,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@property
 	def engine(self):
 		"""
-		This method is the property for **self.__engine** attribute.
+		Property for **self.__engine** attribute.
 
-		:return: self.__engine. ( QObject )
+		:return: self.__engine.
+		:rtype: QObject
 		"""
 
 		return self.__engine
@@ -306,9 +321,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def engine(self, value):
 		"""
-		This method is the setter method for **self.__engine** attribute.
+		Setter for **self.__engine** attribute.
 
-		:param value: Attribute value. ( QObject )
+		:param value: Attribute value.
+		:type value: QObject
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -318,7 +334,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def engine(self):
 		"""
-		This method is the deleter method for **self.__engine** attribute.
+		Deleter for **self.__engine** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -327,9 +343,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@property
 	def iblSetsOutliner(self):
 		"""
-		This method is the property for **self.__iblSetsOutliner** attribute.
+		Property for **self.__iblSetsOutliner** attribute.
 
-		:return: self.__iblSetsOutliner. ( QWidget )
+		:return: self.__iblSetsOutliner.
+		:rtype: QWidget
 		"""
 
 		return self.__iblSetsOutliner
@@ -338,9 +355,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def iblSetsOutliner(self, value):
 		"""
-		This method is the setter method for **self.__iblSetsOutliner** attribute.
+		Setter for **self.__iblSetsOutliner** attribute.
 
-		:param value: Attribute value. ( QWidget )
+		:param value: Attribute value.
+		:type value: QWidget
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -350,7 +368,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def iblSetsOutliner(self):
 		"""
-		This method is the deleter method for **self.__iblSetsOutliner** attribute.
+		Deleter for **self.__iblSetsOutliner** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -359,9 +377,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@property
 	def map(self):
 		"""
-		This method is the property for **self.__map** attribute.
+		Property for **self.__map** attribute.
 
-		:return: self.__map. ( QObject )
+		:return: self.__map.
+		:rtype: QObject
 		"""
 
 		return self.__map
@@ -370,9 +389,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def map(self, value):
 		"""
-		This method is the setter method for **self.__map** attribute.
+		Setter for **self.__map** attribute.
 
-		:param value: Attribute value. ( QObject )
+		:param value: Attribute value.
+		:type value: QObject
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -382,7 +402,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def map(self):
 		"""
-		This method is the deleter method for **self.__map** attribute.
+		Deleter for **self.__map** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -391,9 +411,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@property
 	def mapTypeIds(self):
 		"""
-		This method is the property for **self.__mapTypeIds** attribute.
+		Property for **self.__mapTypeIds** attribute.
 
-		:return: self.__mapTypeIds. ( Tuple )
+		:return: self.__mapTypeIds.
+		:rtype: tuple
 		"""
 
 		return self.__mapTypeIds
@@ -402,9 +423,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def mapTypeIds(self, value):
 		"""
-		This method is the setter method for **self.__mapTypeIds** attribute.
+		Setter for **self.__mapTypeIds** attribute.
 
-		:param value: Attribute value. ( Tuple )
+		:param value: Attribute value.
+		:type value: tuple
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -414,7 +436,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def mapTypeIds(self):
 		"""
-		This method is the deleter method for **self.__mapTypeIds** attribute.
+		Deleter for **self.__mapTypeIds** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -425,10 +447,12 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	#******************************************************************************************************************
 	def activate(self, engine):
 		"""
-		This method activates the Component.
+		Activates the Component.
 
-		:param engine: Engine to attach the Component to. ( QObject )
-		:return: Method success. ( Boolean )
+		:param engine: Engine to attach the Component to.
+		:type engine: QObject
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Activating '{0}' Component.".format(self.__class__.__name__))
@@ -444,9 +468,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 
 	def deactivate(self):
 		"""
-		This method deactivates the Component.
+		Deactivates the Component.
 
-		:return: Method success. ( Boolean )
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Deactivating '{0}' Component.".format(self.__class__.__name__))
@@ -462,9 +487,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 
 	def initializeUi(self):
 		"""
-		This method initializes the Component ui.
-		
-		:return: Method success. ( Boolean )		
+		Initializes the Component ui.
+
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Initializing '{0}' Component ui.".format(self.__class__.__name__))
@@ -496,9 +522,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 
 	def uninitializeUi(self):
 		"""
-		This method uninitializes the Component ui.
-		
-		:return: Method success. ( Boolean )		
+		Uninitializes the Component ui.
+
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		# Signals / Slots.
@@ -518,9 +545,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 
 	def addWidget(self):
 		"""
-		This method adds the Component Widget to the engine.
+		Adds the Component Widget to the engine.
 
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Adding '{0}' Component Widget.".format(self.__class__.__name__))
@@ -531,9 +559,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 
 	def removeWidget(self):
 		"""
-		This method removes the Component Widget from the engine.
+		Removes the Component Widget from the engine.
 
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Removing '{0}' Component Widget.".format(self.__class__.__name__))
@@ -545,9 +574,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 
 	def onClose(self):
 		"""
-		This method is triggered on Framework close.
+		Defines the slot triggered on Framework close.
 
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Calling '{0}' Component Framework 'onClose' method.".format(self.__class__.__name__))
@@ -557,46 +587,52 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 
 	def __iblSetsOutliner_view_selectionModel__selectionChanged(self, selectedItems, deselectedItems):
 		"""
-		This method is triggered when **Data** Model selection has changed.
+		Defines the slot triggered by **Data** Model when selection changed
 
-		:param selectedItems: Selected items. ( QItemSelection )
-		:param deselectedItems: Deselected items. ( QItemSelection )
+		:param selectedItems: Selected items.
+		:type selectedItems: QItemSelection
+		:param deselectedItems: Deselected items.
+		:type deselectedItems: QItemSelection
 		"""
 
 		self.setMarkersUi()
 
 	def __Map_Type_comboBox__activated(self, index):
 		"""
-		This method is triggered when **Map_Type_comboBox** index changes.
+		Defines the slot triggered by **Map_Type_comboBox** when activated.
 
-		:param index: ComboBox activated item index. ( Integer )
+		:param index: ComboBox activated item index.
+		:type index: int
 		"""
 
 		self.__map.setMapType(self.__mapTypeIds[index][1])
 
 	def __Zoom_In_pushButton__clicked(self, checked):
 		"""
-		This method is triggered when **Zoom_In_pushButton** Widget is clicked.
+		Defines the slot triggered by **Zoom_In_pushButton** Widget when clicked.
 
-		:param checked: Checked state. ( Boolean )
+		:param checked: Checked state.
+		:type checked: bool
 		"""
 
 		self.__map.setZoom("In")
 
 	def __Zoom_Out_pushButton__clicked(self, checked):
 		"""
-		This method is triggered when **Zoom_Out_pushButton** Widget is clicked.
+		Defines the slot triggered by **Zoom_Out_pushButton** Widget when clicked.
 
-		:param checked: Checked state. ( Boolean )
+		:param checked: Checked state.
+		:type checked: bool
 		"""
 
 		self.__map.setZoom("Out")
 
 	def __map__loadFinished(self, state):
 		"""
-		This method is triggered when the GPS map finishes loading.
+		Defines the slot triggered by the GPS map when load finished.
 
-		:param state: Loading state. ( Boolean )
+		:param state: Loading state.
+		:type state: bool
 		"""
 
 		self.setMarkersUi()
@@ -604,11 +640,12 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 	@foundations.exceptions.handleExceptions(umbra.exceptions.notifyExceptionHandler, Exception)
 	def setMarkersUi(self):
 		"""
-		This method sets selected Ibl Sets markers.
+		Sets selected Ibl Sets markers.
 
-		:return: Method success. ( Boolean )
-		
-		:note: This method may require user interaction.
+		:return: Method success.
+		:rtype: bool
+
+		:note: May require user interaction.
 		"""
 
 		selectedIblSets = self.__iblSetsOutliner.getSelectedIblSets()
@@ -626,10 +663,12 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 
 	def setMarker(self, iblSet):
 		"""
-		This method sets given Ibl Set marker.
+		Sets given Ibl Set marker.
 
-		:param iblSet: Ibl Set to display marker. ( IblSet )
-		:return: Method success. ( Boolean )
+		:param iblSet: Ibl Set to display marker.
+		:type iblSet: IblSet
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		if not iblSet.latitude and not iblSet.longitude:
@@ -637,7 +676,7 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 
 		LOGGER.debug("> Ibl Set '{0}' provides GEO coordinates.".format(iblSet.name))
 		shotDateString = "<b>Shot Date: </b>{0}".format(
-		sibl_gui.ui.common.getFormatedShotDate(iblSet.date, iblSet.time) or Constants.nullObject)
+		sibl_gui.ui.common.getFormattedShotDate(iblSet.date, iblSet.time) or Constants.nullObject)
 		content = "<p><h3><b>{0}</b></h3></p><p><b>\
 		Author: </b>{1}<br><b>\
 		Location: </b>{2}<br>{3}<br><b>\
@@ -648,9 +687,10 @@ class GpsMap(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 
 	def removeMarkers(self):
 		"""
-		This method removes the GPS map markers.
+		Removes the GPS map markers.
 
-		:return: Method success. ( Boolean )
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		self.__map.removeMarkers()
