@@ -8,7 +8,7 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines the :class:`sibl_gui.components.addons.loaderScriptOptions.loaderScriptOptions.LoaderScriptOptions`
+	Defines the :class:`sibl_gui.components.addons.loaderScriptOptions.loaderScriptOptions.LoaderScriptOptions`
 	Component Interface class Views.
 
 **Others:**
@@ -25,7 +25,7 @@ import umbra.ui.views
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
@@ -40,7 +40,7 @@ LOGGER = foundations.verbose.installLogger()
 #**********************************************************************************************************************
 class TemplatesAttributes_QTableWidget(umbra.ui.views.Abstract_QTableWidget):
 	"""
-	This class is used to display Templates attributes.
+	Defines the view for Templates attributes.
 	"""
 
 	pass
