@@ -8,7 +8,7 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines the :class:`RemoteUpdater` class and others online update related objects.
+	Defines the :class:`RemoteUpdater` class and others online update related objects.
 
 **Others:**
 
@@ -42,6 +42,7 @@ from PyQt4.QtGui import QTableWidgetItem
 #**********************************************************************************************************************
 import foundations.dataStructures
 import foundations.exceptions
+import foundations.io
 import foundations.ui.common
 import foundations.verbose
 import umbra.ui.common
@@ -57,7 +58,7 @@ from umbra.ui.widgets.variable_QPushButton import Variable_QPushButton
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
@@ -74,14 +75,15 @@ UI_FILE = os.path.join(os.path.dirname(__file__), "ui", "Remote_Updater.ui")
 #**********************************************************************************************************************
 class ReleaseObject(foundations.dataStructures.Structure):
 	"""
-	This class represents a storage object for a :class:`RemoteUpdater` class release.
+	Defines a storage object for a :class:`RemoteUpdater` class release.
 	"""
 
 	def __init__(self, **kwargs):
 		"""
-		This method initializes the class.
+		Initializes the class.
 
-		:param kwargs: name, repositoryVersion, localVersion, type, url, comment. ( Key / Value pairs )
+		:param kwargs: name, repositoryVersion, localVersion, type, url, comment.
+		:type kwargs: dict
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
@@ -90,19 +92,23 @@ class ReleaseObject(foundations.dataStructures.Structure):
 
 class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	"""
-	| This class defines the Application remote updater.
+	| Defines the Application remote updater.
 	| The remote updater is initialized with a list of available online releases
 		( List of :class:`ReleaseObject` class instances ).
 	"""
 
 	def __init__(self, parent, releases=None, *args, **kwargs):
 		"""
-		This method initializes the class.
+		Initializes the class.
 
-		:param parent: Object parent. ( QObject )
-		:param releases: Releases. ( Dictionary )
-		:param \*args: Arguments. ( \* )
-		:param \*\*kwargs: Keywords arguments. ( \*\* )
+		:param parent: Object parent.
+		:type parent: QObject
+		:param releases: Releases.
+		:type releases: dict
+		:param \*args: Arguments.
+		:type \*args: \*
+		:param \*\*kwargs: Keywords arguments.
+		:type \*\*kwargs: \*\*
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
@@ -144,9 +150,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def container(self):
 		"""
-		This method is the property for **self.__container** attribute.
+		Property for **self.__container** attribute.
 
-		:return: self.__container. ( QObject )
+		:return: self.__container.
+		:rtype: QObject
 		"""
 
 		return self.__container
@@ -155,9 +162,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def container(self, value):
 		"""
-		This method is the setter method for **self.__container** attribute.
+		Setter for **self.__container** attribute.
 
-		:param value: Attribute value. ( QObject )
+		:param value: Attribute value.
+		:type value: QObject
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -167,7 +175,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def container(self):
 		"""
-		This method is the deleter method for **self.__container** attribute.
+		Deleter for **self.__container** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -176,9 +184,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def releases(self):
 		"""
-		This method is the property for **self.__releases** attribute.
+		Property for **self.__releases** attribute.
 
-		:return: self.__releases. ( Dictionary )
+		:return: self.__releases.
+		:rtype: dict
 		"""
 
 		return self.__releases
@@ -187,9 +196,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(AssertionError)
 	def releases(self, value):
 		"""
-		This method is the setter method for **self.__releases** attribute.
+		Setter for **self.__releases** attribute.
 
-		:param value: Attribute value. ( Dictionary )
+		:param value: Attribute value.
+		:type value: dict
 		"""
 
 		if value is not None:
@@ -205,7 +215,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def releases(self):
 		"""
-		This method is the deleter method for **self.__releases** attribute.
+		Deleter for **self.__releases** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -214,9 +224,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def uiResourcesDirectory(self):
 		"""
-		This method is the property for **self.__uiResourcesDirectory** attribute.
+		Property for **self.__uiResourcesDirectory** attribute.
 
-		:return: self.__uiResourcesDirectory. ( String )
+		:return: self.__uiResourcesDirectory.
+		:rtype: unicode
 		"""
 
 		return self.__uiResourcesDirectory
@@ -225,9 +236,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiResourcesDirectory(self, value):
 		"""
-		This method is the setter method for **self.__uiResourcesDirectory** attribute.
+		Setter for **self.__uiResourcesDirectory** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -237,7 +249,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiResourcesDirectory(self):
 		"""
-		This method is the deleter method for **self.__uiResourcesDirectory** attribute.
+		Deleter for **self.__uiResourcesDirectory** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -246,9 +258,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def uiLogoImage(self):
 		"""
-		This method is the property for **self.__uiLogoImage** attribute.
+		Property for **self.__uiLogoImage** attribute.
 
-		:return: self.__uiLogoImage. ( String )
+		:return: self.__uiLogoImage.
+		:rtype: unicode
 		"""
 
 		return self.__uiLogoImage
@@ -257,9 +270,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiLogoImage(self, value):
 		"""
-		This method is the setter method for **self.__uiLogoImage** attribute.
+		Setter for **self.__uiLogoImage** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -269,7 +283,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiLogoImage(self):
 		"""
-		This method is the deleter method for **self.__uiLogoImage** attribute.
+		Deleter for **self.__uiLogoImage** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -278,9 +292,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def uiTemplatesImage(self):
 		"""
-		This method is the property for **self.__uiTemplatesImage** attribute.
+		Property for **self.__uiTemplatesImage** attribute.
 
-		:return: self.__uiTemplatesImage. ( String )
+		:return: self.__uiTemplatesImage.
+		:rtype: unicode
 		"""
 
 		return self.__uiTemplatesImage
@@ -289,9 +304,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiTemplatesImage(self, value):
 		"""
-		This method is the setter method for **self.__uiTemplatesImage** attribute.
+		Setter for **self.__uiTemplatesImage** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -301,7 +317,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiTemplatesImage(self):
 		"""
-		This method is the deleter method for **self.__uiTemplatesImage** attribute.
+		Deleter for **self.__uiTemplatesImage** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -310,9 +326,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def uiLightGrayColor(self):
 		"""
-		This method is the property for **self.__uiLightGrayColor** attribute.
+		Property for **self.__uiLightGrayColor** attribute.
 
-		:return: self.__uiLightGrayColor. ( QColor )
+		:return: self.__uiLightGrayColor.
+		:rtype: QColor
 		"""
 
 		return self.__uiLightGrayColor
@@ -321,9 +338,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiLightGrayColor(self, value):
 		"""
-		This method is the setter method for **self.__uiLightGrayColor** attribute.
+		Setter for **self.__uiLightGrayColor** attribute.
 
-		:param value: Attribute value. ( QColor )
+		:param value: Attribute value.
+		:type value: QColor
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -333,7 +351,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiLightGrayColor(self):
 		"""
-		This method is the deleter method for **self.__uiLightGrayColor** attribute.
+		Deleter for **self.__uiLightGrayColor** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -342,9 +360,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def uiDarkGrayColor(self):
 		"""
-		This method is the property for **self.__uiDarkGrayColor** attribute.
+		Property for **self.__uiDarkGrayColor** attribute.
 
-		:return: self.__uiDarkGrayColor. ( QColor )
+		:return: self.__uiDarkGrayColor.
+		:rtype: QColor
 		"""
 
 		return self.__uiDarkGrayColor
@@ -353,9 +372,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiDarkGrayColor(self, value):
 		"""
-		This method is the setter method for **self.__uiDarkGrayColor** attribute.
+		Setter for **self.__uiDarkGrayColor** attribute.
 
-		:param value: Attribute value. ( QColor )
+		:param value: Attribute value.
+		:type value: QColor
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -365,7 +385,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiDarkGrayColor(self):
 		"""
-		This method is the deleter method for **self.__uiDarkGrayColor** attribute.
+		Deleter for **self.__uiDarkGrayColor** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -374,9 +394,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def view(self):
 		"""
-		This method is the property for **self.__view** attribute.
+		Property for **self.__view** attribute.
 
-		:return: self.__view. ( QWidget )
+		:return: self.__view.
+		:rtype: QWidget
 		"""
 
 		return self.__view
@@ -385,9 +406,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def view(self, value):
 		"""
-		This method is the setter method for **self.__view** attribute.
+		Setter for **self.__view** attribute.
 
-		:param value: Attribute value. ( QWidget )
+		:param value: Attribute value.
+		:type value: QWidget
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -397,7 +419,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def view(self):
 		"""
-		This method is the deleter method for **self.__view** attribute.
+		Deleter for **self.__view** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -406,9 +428,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def splitter(self):
 		"""
-		This method is the property for **self.__splitter** attribute.
+		Property for **self.__splitter** attribute.
 
-		:return: self.__splitter. ( String )
+		:return: self.__splitter.
+		:rtype: unicode
 		"""
 
 		return self.__splitter
@@ -417,9 +440,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def splitter(self, value):
 		"""
-		This method is the setter method for **self.__splitter** attribute.
+		Setter for **self.__splitter** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -429,7 +453,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def splitter(self):
 		"""
-		This method is the deleter method for **self.__splitter** attribute.
+		Deleter for **self.__splitter** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -438,9 +462,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def headers(self):
 		"""
-		This method is the property for **self.__headers** attribute.
+		Property for **self.__headers** attribute.
 
-		:return: self.__headers. ( String )
+		:return: self.__headers.
+		:rtype: unicode
 		"""
 
 		return self.__headers
@@ -449,9 +474,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def headers(self, value):
 		"""
-		This method is the setter method for **self.__headers** attribute.
+		Setter for **self.__headers** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -461,7 +487,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def headers(self):
 		"""
-		This method is the deleter method for **self.__headers** attribute.
+		Deleter for **self.__headers** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -470,9 +496,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def applicationChangesUrl(self):
 		"""
-		This method is the property for **self.__applicationChangesUrl** attribute.
+		Property for **self.__applicationChangesUrl** attribute.
 
-		:return: self.__applicationChangesUrl. ( String )
+		:return: self.__applicationChangesUrl.
+		:rtype: unicode
 		"""
 
 		return self.__applicationChangesUrl
@@ -481,9 +508,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def applicationChangesUrl(self, value):
 		"""
-		This method is the setter method for **self.__applicationChangesUrl** attribute.
+		Setter for **self.__applicationChangesUrl** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -493,7 +521,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def applicationChangesUrl(self):
 		"""
-		This method is the deleter method for **self.__applicationChangesUrl** attribute.
+		Deleter for **self.__applicationChangesUrl** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -502,9 +530,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def repositoryUrl(self):
 		"""
-		This method is the property for **self.__repositoryUrl** attribute.
+		Property for **self.__repositoryUrl** attribute.
 
-		:return: self.__repositoryUrl. ( String )
+		:return: self.__repositoryUrl.
+		:rtype: unicode
 		"""
 
 		return self.__repositoryUrl
@@ -513,9 +542,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def repositoryUrl(self, value):
 		"""
-		This method is the setter method for **self.__repositoryUrl** attribute.
+		Setter for **self.__repositoryUrl** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -525,7 +555,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def repositoryUrl(self):
 		"""
-		This method is the deleter method for **self.__repositoryUrl** attribute.
+		Deleter for **self.__repositoryUrl** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -534,9 +564,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def downloadManager(self):
 		"""
-		This method is the property for **self.__downloadManager** attribute.
+		Property for **self.__downloadManager** attribute.
 
-		:return: self.__downloadManager. ( Object )
+		:return: self.__downloadManager.
+		:rtype: object
 		"""
 
 		return self.__downloadManager
@@ -545,9 +576,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def downloadManager(self, value):
 		"""
-		This method is the setter method for **self.__downloadManager** attribute.
+		Setter for **self.__downloadManager** attribute.
 
-		:param value: Attribute value. ( Object )
+		:param value: Attribute value.
+		:type value: object
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -557,7 +589,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def downloadManager(self):
 		"""
-		This method is the deleter method for **self.__downloadManager** attribute.
+		Deleter for **self.__downloadManager** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -566,9 +598,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@property
 	def networkAccessManager(self):
 		"""
-		This method is the property for **self.__networkAccessManager** attribute.
+		Property for **self.__networkAccessManager** attribute.
 
-		:return: self.__networkAccessManager. ( QNetworkAccessManager )
+		:return: self.__networkAccessManager.
+		:rtype: QNetworkAccessManager
 		"""
 
 		return self.__networkAccessManager
@@ -577,9 +610,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def networkAccessManager(self, value):
 		"""
-		This method is the setter method for **self.__networkAccessManager** attribute.
+		Setter for **self.__networkAccessManager** attribute.
 
-		:param value: Attribute value. ( QNetworkAccessManager )
+		:param value: Attribute value.
+		:type value: QNetworkAccessManager
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -589,7 +623,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def networkAccessManager(self):
 		"""
-		This method is the deleter method for **self.__networkAccessManager** attribute.
+		Deleter for **self.__networkAccessManager** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -600,7 +634,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 	#******************************************************************************************************************
 	def __initializeUi(self):
 		"""
-		This method initializes the Widget ui.
+		Initializes the Widget ui.
 		"""
 
 		umbra.ui.common.setWindowDefaultIcon(self)
@@ -683,9 +717,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 
 	def __Get_sIBL_GUI_pushButton__clicked(self, checked):
 		"""
-		This method is triggered when **Get_sIBL_GUI_pushButton** Widget is clicked.
+		Defines the slot triggered by **Get_sIBL_GUI_pushButton** Widget when clicked.
 
-		:param checked: Checked state. ( Boolean )
+		:param checked: Checked state.
+		:type checked: bool
 		"""
 		urlTokens = self.releases[Constants.applicationName].url.split(self.__splitter)
 		builds = dict(((urlTokens[i].strip(), urlTokens[i + 1].strip(" \"")) for i in range(0, len(urlTokens), 2)))
@@ -708,9 +743,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 
 	def __Get_Latest_Templates_pushButton__clicked(self, checked):
 		"""
-		This method is triggered when **Get_Latest_Templates_pushButton** Widget is clicked.
+		Defines the slot triggered by **Get_Latest_Templates_pushButton** Widget when clicked.
 
-		:param checked: Checked state. ( Boolean )
+		:param checked: Checked state.
+		:type checked: bool
 		"""
 
 		requests = []
@@ -725,6 +761,12 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 		if not downloadDirectory:
 			return
 
+		if not foundations.io.isWritable(downloadDirectory):
+			self.__container.engine.notificationsManager.exceptify(
+					"{0} | '{1}' directory is not writable".format(
+					self.__class__.__name__, downloadDirectory))
+			return
+
 		LOGGER.debug("> Templates download directory: '{0}'.".format(downloadDirectory))
 		self.__downloadManager = DownloadManager(self,
 												self.__networkAccessManager,
@@ -737,9 +779,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 
 	def __Open_Repository_pushButton__clicked(self, checked):
 		"""
-		This method is triggered when **Open_Repository_pushButton** Widget is clicked.
+		Defines the slot triggered by **Open_Repository_pushButton** Widget when clicked.
 
-		:param checked: Checked state. ( Boolean )
+		:param checked: Checked state.
+		:type checked: bool
 		"""
 
 		LOGGER.debug("> Opening url: '{0}'.".format(self.__repositoryUrl))
@@ -747,9 +790,10 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 
 	def __Close_pushButton__clicked(self, checked):
 		"""
-		This method closes the RemoteUpdater.
+		Closes the RemoteUpdater.
 
-		:param checked: Checked state. ( Boolean )
+		:param checked: Checked state.
+		:type checked: bool
 		"""
 
 		LOGGER.info("{0} | Closing '{1}' updater!".format(self.__class__.__name__, Constants.applicationName))
@@ -757,7 +801,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 
 	def __downloadManager__finished(self):
 		"""
-		This method is triggered when the download Manager finishes.
+		Defines the slot triggered by the download Manager when finished.
 		"""
 
 		for download, data in self.__downloadManager.downloads.iteritems():
@@ -785,7 +829,7 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 
 	def __getTemplatesDownloadDirectory(self):
 		"""
-		This method gets the Templates directory.
+		Gets the Templates directory.
 		"""
 
 		LOGGER.debug("> Retrieving Templates download directory.")
@@ -808,10 +852,12 @@ class RemoteUpdater(foundations.ui.common.QWidgetFactory(uiFile=UI_FILE)):
 
 	def extractZipFile(self, file):
 		"""
-		This method uncompress the given zip file.
+		Uncompress the given zip file.
 
-		:param file: File to extract. ( String )
-		:return: Extraction success. ( Boolean )
+		:param file: File to extract.
+		:type file: unicode
+		:return: Extraction success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Initializing '{0}' file uncompress.".format(file))
