@@ -8,7 +8,7 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines the :class:`Preview` Component Interface class, the :class:`ImagesPreviewer` class and
+	Defines the :class:`Preview` Component Interface class, the :class:`ImagesPreviewer` class and
 	others images preview related objects.
 
 **Others:**
@@ -54,7 +54,7 @@ from umbra.globals.runtimeGlobals import RuntimeGlobals
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
@@ -71,18 +71,22 @@ COMPONENT_UI_FILE = os.path.join(os.path.dirname(__file__), "ui", "Preview.ui")
 #**********************************************************************************************************************
 class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	"""
-	| This class is the :mod:`sibl_gui.components.addons.preview.preview` Component Interface class.
+	| Defines the :mod:`sibl_gui.components.addons.preview.preview` Component Interface class.
 	| It provides a basic image previewer.
 	"""
 
 	def __init__(self, parent=None, name=None, *args, **kwargs):
 		"""
-		This method initializes the class.
+		Initializes the class.
 
-		:param parent: Object parent. ( QObject )
-		:param name: Component name. ( String )
-		:param \*args: Arguments. ( \* )
-		:param \*\*kwargs: Keywords arguments. ( \*\* )
+		:param parent: Object parent.
+		:type parent: QObject
+		:param name: Component name.
+		:type name: unicode
+		:param \*args: Arguments.
+		:type \*args: \*
+		:param \*\*kwargs: Keywords arguments.
+		:type \*\*kwargs: \*\*
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
@@ -128,9 +132,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def uiResourcesDirectory(self):
 		"""
-		This method is the property for **self.__uiResourcesDirectory** attribute.
+		Property for **self.__uiResourcesDirectory** attribute.
 
-		:return: self.__uiResourcesDirectory. ( String )
+		:return: self.__uiResourcesDirectory.
+		:rtype: unicode
 		"""
 
 		return self.__uiResourcesDirectory
@@ -139,9 +144,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiResourcesDirectory(self, value):
 		"""
-		This method is the setter method for **self.__uiResourcesDirectory** attribute.
+		Setter for **self.__uiResourcesDirectory** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -151,7 +157,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def uiResourcesDirectory(self):
 		"""
-		This method is the deleter method for **self.__uiResourcesDirectory** attribute.
+		Deleter for **self.__uiResourcesDirectory** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -160,9 +166,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def engine(self):
 		"""
-		This method is the property for **self.__engine** attribute.
+		Property for **self.__engine** attribute.
 
-		:return: self.__engine. ( QObject )
+		:return: self.__engine.
+		:rtype: QObject
 		"""
 
 		return self.__engine
@@ -171,9 +178,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def engine(self, value):
 		"""
-		This method is the setter method for **self.__engine** attribute.
+		Setter for **self.__engine** attribute.
 
-		:param value: Attribute value. ( QObject )
+		:param value: Attribute value.
+		:type value: QObject
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -183,7 +191,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def engine(self):
 		"""
-		This method is the deleter method for **self.__engine** attribute.
+		Deleter for **self.__engine** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -192,9 +200,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def settings(self):
 		"""
-		This method is the property for **self.__settings** attribute.
+		Property for **self.__settings** attribute.
 
-		:return: self.__settings. ( QSettings )
+		:return: self.__settings.
+		:rtype: QSettings
 		"""
 
 		return self.__settings
@@ -203,9 +212,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def settings(self, value):
 		"""
-		This method is the setter method for **self.__settings** attribute.
+		Setter for **self.__settings** attribute.
 
-		:param value: Attribute value. ( QSettings )
+		:param value: Attribute value.
+		:type value: QSettings
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -215,7 +225,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def settings(self):
 		"""
-		This method is the deleter method for **self.__settings** attribute.
+		Deleter for **self.__settings** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -224,9 +234,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def settingsSection(self):
 		"""
-		This method is the property for **self.__settingsSection** attribute.
+		Property for **self.__settingsSection** attribute.
 
-		:return: self.__settingsSection. ( String )
+		:return: self.__settingsSection.
+		:rtype: unicode
 		"""
 
 		return self.__settingsSection
@@ -235,9 +246,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def settingsSection(self, value):
 		"""
-		This method is the setter method for **self.__settingsSection** attribute.
+		Setter for **self.__settingsSection** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -247,7 +259,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def settingsSection(self):
 		"""
-		This method is the deleter method for **self.__settingsSection** attribute.
+		Deleter for **self.__settingsSection** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -256,9 +268,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def preferencesManager(self):
 		"""
-		This method is the property for **self.__preferencesManager** attribute.
+		Property for **self.__preferencesManager** attribute.
 
-		:return: self.__preferencesManager. ( QWidget )
+		:return: self.__preferencesManager.
+		:rtype: QWidget
 		"""
 
 		return self.__preferencesManager
@@ -267,9 +280,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def preferencesManager(self, value):
 		"""
-		This method is the setter method for **self.__preferencesManager** attribute.
+		Setter for **self.__preferencesManager** attribute.
 
-		:param value: Attribute value. ( QWidget )
+		:param value: Attribute value.
+		:type value: QWidget
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -279,7 +293,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def preferencesManager(self):
 		"""
-		This method is the deleter method for **self.__preferencesManager** attribute.
+		Deleter for **self.__preferencesManager** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -288,9 +302,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def iblSetsOutliner(self):
 		"""
-		This method is the property for **self.__iblSetsOutliner** attribute.
+		Property for **self.__iblSetsOutliner** attribute.
 
-		:return: self.__iblSetsOutliner. ( QWidget )
+		:return: self.__iblSetsOutliner.
+		:rtype: QWidget
 		"""
 
 		return self.__iblSetsOutliner
@@ -299,9 +314,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def iblSetsOutliner(self, value):
 		"""
-		This method is the setter method for **self.__iblSetsOutliner** attribute.
+		Setter for **self.__iblSetsOutliner** attribute.
 
-		:param value: Attribute value. ( QWidget )
+		:param value: Attribute value.
+		:type value: QWidget
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -311,7 +327,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def iblSetsOutliner(self):
 		"""
-		This method is the deleter method for **self.__iblSetsOutliner** attribute.
+		Deleter for **self.__iblSetsOutliner** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -320,9 +336,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def inspector(self):
 		"""
-		This method is the property for **self.__inspector** attribute.
+		Property for **self.__inspector** attribute.
 
-		:return: self.__inspector. ( QWidget )
+		:return: self.__inspector.
+		:rtype: QWidget
 		"""
 
 		return self.__inspector
@@ -331,9 +348,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def inspector(self, value):
 		"""
-		This method is the setter method for **self.__inspector** attribute.
+		Setter for **self.__inspector** attribute.
 
-		:param value: Attribute value. ( QWidget )
+		:param value: Attribute value.
+		:type value: QWidget
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -343,7 +361,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def inspector(self):
 		"""
-		This method is the deleter method for **self.__inspector** attribute.
+		Deleter for **self.__inspector** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -352,9 +370,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def imagesPreviewers(self):
 		"""
-		This method is the property for **self.__imagesPreviewers** attribute.
+		Property for **self.__imagesPreviewers** attribute.
 
-		:return: self.__imagesPreviewers. ( List )
+		:return: self.__imagesPreviewers.
+		:rtype: list
 		"""
 
 		return self.__imagesPreviewers
@@ -363,9 +382,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def imagesPreviewers(self, value):
 		"""
-		This method is the setter method for **self.__imagesPreviewers** attribute.
+		Setter for **self.__imagesPreviewers** attribute.
 
-		:param value: Attribute value. ( List )
+		:param value: Attribute value.
+		:type value: list
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -375,7 +395,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def imagesPreviewers(self):
 		"""
-		This method is the deleter method for **self.__imagesPreviewers** attribute.
+		Deleter for **self.__imagesPreviewers** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -384,9 +404,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def maximumImagesPreviewersInstances(self):
 		"""
-		This method is the property for **self.__maximumImagesPreviewersInstances** attribute.
+		Property for **self.__maximumImagesPreviewersInstances** attribute.
 
-		:return: self.__maximumImagesPreviewersInstances. ( Integer )
+		:return: self.__maximumImagesPreviewersInstances.
+		:rtype: int
 		"""
 
 		return self.__maximumImagesPreviewersInstances
@@ -395,9 +416,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def maximumImagesPreviewersInstances(self, value):
 		"""
-		This method is the setter method for **self.__maximumImagesPreviewersInstances** attribute.
+		Setter for **self.__maximumImagesPreviewersInstances** attribute.
 
-		:param value: Attribute value. ( Integer )
+		:param value: Attribute value.
+		:type value: int
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -407,7 +429,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def maximumImagesPreviewersInstances(self):
 		"""
-		This method is the deleter method for **self.__maximumImagesPreviewersInstances** attribute.
+		Deleter for **self.__maximumImagesPreviewersInstances** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -416,9 +438,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def inspectorButtons(self):
 		"""
-		This method is the property for **self.__inspectorButtons** attribute.
+		Property for **self.__inspectorButtons** attribute.
 
-		:return: self.__inspectorButtons. ( Dictionary )
+		:return: self.__inspectorButtons.
+		:rtype: dict
 		"""
 
 		return self.__inspectorButtons
@@ -427,9 +450,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def inspectorButtons(self, value):
 		"""
-		This method is the setter method for **self.__inspectorButtons** attribute.
+		Setter for **self.__inspectorButtons** attribute.
 
-		:param value: Attribute value. ( Dictionary )
+		:param value: Attribute value.
+		:type value: dict
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -439,7 +463,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def inspectorButtons(self):
 		"""
-		This method is the deleter method for **self.__inspectorButtons** attribute.
+		Deleter for **self.__inspectorButtons** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -450,10 +474,12 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	#******************************************************************************************************************
 	def activate(self, engine):
 		"""
-		This method activates the Component.
+		Activates the Component.
 
-		:param engine: Engine to attach the Component to. ( QObject )
-		:return: Method success. ( Boolean )
+		:param engine: Engine to attach the Component to.
+		:type engine: QObject
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Activating '{0}' Component.".format(self.__class__.__name__))
@@ -474,9 +500,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def deactivate(self):
 		"""
-		This method deactivates the Component.
+		Deactivates the Component.
 
-		:return: Method success. ( Boolean )
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Deactivating '{0}' Component.".format(self.__class__.__name__))
@@ -498,9 +525,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def initializeUi(self):
 		"""
-		This method initializes the Component ui.
+		Initializes the Component ui.
 		
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Initializing '{0}' Component ui.".format(self.__class__.__name__))
@@ -519,9 +547,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def uninitializeUi(self):
 		"""
-		This method uninitializes the Component ui.
+		Uninitializes the Component ui.
 		
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Uninitializing '{0}' Component ui.".format(self.__class__.__name__))
@@ -538,9 +567,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def addWidget(self):
 		"""
-		This method adds the Component Widget to the engine.
+		Adds the Component Widget to the engine.
 
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Adding '{0}' Component Widget.".format(self.__class__.__name__))
@@ -551,9 +581,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def removeWidget(self):
 		"""
-		This method removes the Component Widget from the engine.
+		Removes the Component Widget from the engine.
 
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Removing '{0}' Component Widget.".format(self.__class__.__name__))
@@ -565,7 +596,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def __addActions(self):
 		"""
-		This method sets Component actions.
+		Sets Component actions.
 		"""
 
 		LOGGER.debug("> Adding '{0}' Component actions.".format(self.__class__.__name__))
@@ -612,7 +643,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def __removeActions(self):
 		"""
-		This method removes actions.
+		Removes actions.
 		"""
 
 		LOGGER.debug("> Removing '{0}' Component actions.".format(self.__class__.__name__))
@@ -645,7 +676,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def __addInspectorButtons(self):
 		"""
-		This method adds buttons to the :mod:`sibl_gui.components.core.inspector.inspector` Component.
+		Adds buttons to the :mod:`sibl_gui.components.core.inspector.inspector` Component.
 		"""
 
 		self.__inspector.Inspector_Options_groupBox.show()
@@ -658,7 +689,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def __removeInspectorButtons(self):
 		"""
-		This method removes buttons from the :mod:`sibl_gui.components.core.inspector.inspector` Component.
+		Removes buttons from the :mod:`sibl_gui.components.core.inspector.inspector` Component.
 		"""
 
 		for value in self.__inspectorButtons.itervalues():
@@ -666,87 +697,103 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def __iblSetsOutliner_views_viewIblSetsBackgroundImagesAction__triggered(self, checked):
 		"""
-		This method is triggered by **'Actions|Umbra|Components|core.iblSetsOutliner|View Background Image ...'** action.
+		Defines the slot triggered by **'Actions|Umbra|Components|core.iblSetsOutliner|View Background Image ...'** action.
 
-		:param checked: Action checked state. ( Boolean )
-		:return: Method success. ( Boolean )
+		:param checked: Action checked state.
+		:type checked: bool
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		return self.viewIblSetsImagesUi("Background")
 
 	def __iblSetsOutliner_views_viewIblSetsLightingImagesAction__triggered(self, checked):
 		"""
-		This method is triggered by **'Actions|Umbra|Components|core.iblSetsOutliner|View Lighting Image ...'** action.
+		Defines the slot triggered by **'Actions|Umbra|Components|core.iblSetsOutliner|View Lighting Image ...'** action.
 
-		:param checked: Action checked state. ( Boolean )
-		:return: Method success. ( Boolean )
+		:param checked: Action checked state.
+		:type checked: bool
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		return self.viewIblSetsImagesUi("Lighting")
 
 	def __iblSetsOutliner_views_viewIblSetsReflectionImagesAction__triggered(self, checked):
 		"""
-		This method is triggered by **'Actions|Umbra|Components|core.iblSetsOutliner|View Reflection Image ...'** action.
+		Defines the slot triggered by **'Actions|Umbra|Components|core.iblSetsOutliner|View Reflection Image ...'** action.
 
-		:param checked: Action checked state. ( Boolean )
-		:return: Method success. ( Boolean )
+		:param checked: Action checked state.
+		:type checked: bool
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		return self.viewIblSetsImagesUi("Reflection")
 
 	def __iblSetsOutliner_views_viewIblSetsPlatesAction__triggered(self, checked):
 		"""
-		This method is triggered by **'Actions|Umbra|Components|core.iblSetsOutliner|View Plate(s) ...'** action.
+		Defines the slot triggered by **'Actions|Umbra|Components|core.iblSetsOutliner|View Plate(s) ...'** action.
 
-		:param checked: Action checked state. ( Boolean )
-		:return: Method success. ( Boolean )
+		:param checked: Action checked state.
+		:type checked: bool
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		return self.viewIblSetsImagesUi("Plate")
 
 	def __Inspector_Overall_frame_viewActiveIblSetBackgroundImageAction__triggered(self, checked):
 		"""
-		This method is triggered by **'Actions|Umbra|Components|core.inspector|View Background Image ...'** action.
+		Defines the slot triggered by **'Actions|Umbra|Components|core.inspector|View Background Image ...'** action.
 
-		:param checked: Action checked state. ( Boolean )
-		:return: Method success. ( Boolean )
+		:param checked: Action checked state.
+		:type checked: bool
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		return self.viewActiveIblSetImagesUi("Background")
 
 	def __Inspector_Overall_frame_viewActiveIblSetLightingImageAction__triggered(self, checked):
 		"""
-		This method is triggered by **'Actions|Umbra|Components|core.inspector|View Lighting Image ...'** action.
+		Defines the slot triggered by **'Actions|Umbra|Components|core.inspector|View Lighting Image ...'** action.
 
-		:param checked: Action checked state. ( Boolean )
-		:return: Method success. ( Boolean )
+		:param checked: Action checked state.
+		:type checked: bool
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		return self.viewActiveIblSetImagesUi("Lighting")
 
 	def __Inspector_Overall_frame_viewActiveIblSetReflectionImageAction__triggered(self, checked):
 		"""
-		This method is triggered by **'"Actions|Umbra|Components|core.inspector|View Reflection Image ...'** action.
+		Defines the slot triggered by **'"Actions|Umbra|Components|core.inspector|View Reflection Image ...'** action.
 
-		:param checked: Action checked state. ( Boolean )
-		:return: Method success. ( Boolean )
+		:param checked: Action checked state.
+		:type checked: bool
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		return self.viewActiveIblSetImagesUi("Reflection")
 
 	def __Inspector_Overall_frame_viewActiveIblSetPlatesAction__triggered(self, checked):
 		"""
-		This method is triggered by **'Actions|Umbra|Components|core.inspector|View Plate(s) ...'** action.
+		Defines the slot triggered by **'Actions|Umbra|Components|core.inspector|View Plate(s) ...'** action.
 
-		:param checked: Action checked state. ( Boolean )
-		:return: Method success. ( Boolean )
+		:param checked: Action checked state.
+		:type checked: bool
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		return self.viewActiveIblSetImagesUi("Plate")
 
 	def __Custom_Previewer_Path_lineEdit_setUi(self):
 		"""
-		This method fills **Custom_Previewer_Path_lineEdit** Widget.
+		Fills **Custom_Previewer_Path_lineEdit** Widget.
 		"""
 
 		customPreviewer = self.__settings.getKey(self.__settingsSection, "customPreviewer")
@@ -756,9 +803,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def __Custom_Previewer_Path_toolButton__clicked(self, checked):
 		"""
-		This method is triggered when **Custom_Previewer_Path_toolButton** Widget is clicked.
+		Defines the slot triggered by **Custom_Previewer_Path_toolButton** Widget when clicked.
 
-		:param checked: Checked state. ( Boolean )
+		:param checked: Checked state.
+		:type checked: bool
 		"""
 
 		customPreviewerExecutable = umbra.ui.common.storeLastBrowsedPath(
@@ -774,7 +822,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 											foundations.exceptions.UserError)
 	def __Custom_Previewer_Path_lineEdit__editFinished(self):
 		"""
-		This method is triggered when **Custom_Previewer_Path_lineEdit** Widget is edited and check that entered path is valid.
+		Defines the slot triggered by **Custom_Previewer_Path_lineEdit** Widget when edited and check that entered path is valid.
 		"""
 
 		value = foundations.strings.toString(self.Custom_Previewer_Path_lineEdit.text())
@@ -789,9 +837,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def __hasMaximumImagesPreviewersInstances(self):
 		"""
-		This method returns if the maximum Previewers instances allowed is reached.
+		Returns if the maximum Previewers instances allowed is reached.
 
-		:return: Maximum instances reached. ( Boolean )
+		:return: Maximum instances reached.
+		:rtype: bool
 		"""
 
 		if len(self.__imagesPreviewers) >= self.__maximumImagesPreviewersInstances:
@@ -805,13 +854,16 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(umbra.exceptions.notifyExceptionHandler, Exception)
 	def viewIblSetsImagesUi(self, imageType, *args):
 		"""
-		This method launches selected Ibl Sets Images Previewer.
+		Launches selected Ibl Sets Images Previewer.
 
-		:param imageType: Image type. ( String )
-		:param \*args: Arguments. ( \* )
-		:return: Method success. ( Boolean )
+		:param imageType: Image type.
+		:type imageType: unicode
+		:param \*args: Arguments.
+		:type \*args: \*
+		:return: Method success.
+		:rtype: bool
 		
-		:note: This method may require user interaction.
+		:note: May require user interaction.
 		"""
 
 		selectedIblSets = self.__iblSetsOutliner.getSelectedIblSets()
@@ -840,13 +892,16 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 											Exception)
 	def viewActiveIblSetImagesUi(self, imageType, *args):
 		"""
-		This method launches :mod:`sibl_gui.components.core.inspector.inspector` Component Ibl Set Images Previewer.
+		Launches :mod:`sibl_gui.components.core.inspector.inspector` Component Ibl Set Images Previewer.
 
-		:param imageType: Image type. ( String )
-		:param \*args: Arguments. ( \* )
-		:return: Method success. ( Boolean )
+		:param imageType: Image type.
+		:type imageType: unicode
+		:param \*args: Arguments.
+		:type \*args: \*
+		:return: Method success.
+		:rtype: bool
 		
-		:note: This method may require user interaction.
+		:note: May require user interaction.
 		"""
 
 		activeIblSet = self.__inspector.activeIblSet
@@ -878,10 +933,12 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(umbra.exceptions.notifyExceptionHandler, Exception)
 	def viewImages(self, paths, customPreviewer=None):
 		"""
-		This method launches an Ibl Set Images Previewer.
+		Launches an Ibl Set Images Previewer.
 
-		:param paths: Image paths. ( List )
-		:param customPreviewer: Custom previewer. ( String )
+		:param paths: Image paths.
+		:type paths: list
+		:param customPreviewer: Custom previewer.
+		:type customPreviewer: unicode
 		"""
 
 		if customPreviewer:
@@ -905,10 +962,12 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def addImagesPreviewer(self, imagesPreviewer):
 		"""
-		This method adds an Images Previewer.
+		Adds an Images Previewer.
 
-		:param imagesPreviewer: Images Previewer. ( ImagesPreviewer )
-		:return: Method success. ( Boolean )
+		:param imagesPreviewer: Images Previewer.
+		:type imagesPreviewer: ImagesPreviewer
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Adding '{0}' Images Previewer.".format(imagesPreviewer))
@@ -918,9 +977,10 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def removeImagesPreviewer(self, imagesPreviewer):
 		"""
-		This method removes an Images Previewer.
+		Removes an Images Previewer.
 
-		:param imagesPreviewer: Images Previewer. ( ImagesPreviewer )
+		:param imagesPreviewer: Images Previewer.
+		:type imagesPreviewer: ImagesPreviewer
 		"""
 
 		LOGGER.debug("> Removing '{0}' Images Previewer.".format(imagesPreviewer))
@@ -932,10 +992,12 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@umbra.engine.showProcessing("Reading Images...")
 	def getImagesPreviewer(self, paths):
 		"""
-		This method launches an Images Previewer.
+		Launches an Images Previewer.
 
-		:param paths: Images paths. ( List )
-		:return: Method success. ( Boolean )
+		:param paths: Images paths.
+		:type paths: list
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Launching Images Previewer for '{0}' images.".format(", ".join(paths)))
@@ -946,11 +1008,14 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def getProcessCommand(self, paths, customPreviewer):
 		"""
-		This method gets process command.
+		Gets process command.
 
-		:param paths: Paths to preview. ( String )
-		:param customPreviewer: Custom browser. ( String )
-		:return: Process command. ( String )
+		:param paths: Paths to preview.
+		:type paths: unicode
+		:param customPreviewer: Custom browser.
+		:type customPreviewer: unicode
+		:return: Process command.
+		:rtype: unicode
 		"""
 
 		processCommand = None
@@ -965,11 +1030,14 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def getIblSetImagesPaths(self, iblSet, imageType):
 		"""
-		This method gets Ibl Set images paths.
+		Gets Ibl Set images paths.
 
-		:param iblSet: Ibl Set. ( IblSet )
-		:param imageType: Image type. ( String )
-		:return: Images paths. ( List )
+		:param iblSet: Ibl Set.
+		:type iblSet: IblSet
+		:param imageType: Image type.
+		:type imageType: unicode
+		:return: Images paths.
+		:rtype: list
 		"""
 
 		imagePaths = []
@@ -986,7 +1054,7 @@ class Preview(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 			if foundations.common.pathExists(iblSet.path):
 				LOGGER.debug("> Parsing Inspector Ibl Set file: '{0}'.".format(iblSet))
 				sectionsFileParser = SectionsFileParser(iblSet.path)
-				sectionsFileParser.read() and sectionsFileParser.parse()
+				sectionsFileParser.parse()
 				for section in sectionsFileParser.sections:
 					if re.search(r"Plate\d+", section):
 						imagePaths.append(os.path.normpath(os.path.join(os.path.dirname(iblSet.path),
