@@ -8,7 +8,7 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines the :class:`SearchDatabase` Component Interface class.
+	Defines the :class:`SearchDatabase` Component Interface class.
 
 **Others:**
 
@@ -49,7 +49,7 @@ from umbra.ui.widgets.search_QLineEdit import Search_QLineEdit
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
@@ -66,18 +66,22 @@ COMPONENT_UI_FILE = os.path.join(os.path.dirname(__file__), "ui", "Search_Databa
 #**********************************************************************************************************************
 class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	"""
-	| This class is the :mod:`sibl_gui.components.addons.searchDatabase.searchDatabase` Component Interface class.
+	| Defines the :mod:`sibl_gui.components.addons.searchDatabase.searchDatabase` Component Interface class.
 	| It provides methods for the user to search into the Database using various filters.
 	"""
 
 	def __init__(self, parent=None, name=None, *args, **kwargs):
 		"""
-		This method initializes the class.
+		Initializes the class.
 
-		:param parent: Object parent. ( QObject )
-		:param name: Component name. ( String )
-		:param \*args: Arguments. ( \* )
-		:param \*\*kwargs: Keywords arguments. ( \*\* )
+		:param parent: Object parent.
+		:type parent: QObject
+		:param name: Component name.
+		:type name: unicode
+		:param \*args: Arguments.
+		:type \*args: \*
+		:param \*\*kwargs: Keywords arguments.
+		:type \*\*kwargs: \*\*
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
@@ -105,9 +109,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def dockArea(self):
 		"""
-		This method is the property for **self.__dockArea** attribute.
+		Property for **self.__dockArea** attribute.
 
-		:return: self.__dockArea. ( Integer )
+		:return: self.__dockArea.
+		:rtype: int
 		"""
 
 		return self.__dockArea
@@ -116,9 +121,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def dockArea(self, value):
 		"""
-		This method is the setter method for **self.__dockArea** attribute.
+		Setter for **self.__dockArea** attribute.
 
-		:param value: Attribute value. ( Integer )
+		:param value: Attribute value.
+		:type value: int
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -128,7 +134,7 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def dockArea(self):
 		"""
-		This method is the deleter method for **self.__dockArea** attribute.
+		Deleter for **self.__dockArea** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -137,9 +143,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def viewSpacing(self):
 		"""
-		This method is the property for **self.__viewSpacing** attribute.
+		Property for **self.__viewSpacing** attribute.
 
-		:return: self.__viewSpacing. ( Integer )
+		:return: self.__viewSpacing.
+		:rtype: int
 		"""
 
 		return self.__viewSpacing
@@ -148,9 +155,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def viewSpacing(self, value):
 		"""
-		This method is the setter method for **self.__viewSpacing** attribute.
+		Setter for **self.__viewSpacing** attribute.
 
-		:param value: Attribute value. ( Integer )
+		:param value: Attribute value.
+		:type value: int
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -160,7 +168,7 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def viewSpacing(self):
 		"""
-		This method is the deleter method for **self.__viewSpacing** attribute.
+		Deleter for **self.__viewSpacing** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -169,9 +177,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def engine(self):
 		"""
-		This method is the property for **self.__engine** attribute.
+		Property for **self.__engine** attribute.
 
-		:return: self.__engine. ( QObject )
+		:return: self.__engine.
+		:rtype: QObject
 		"""
 
 		return self.__engine
@@ -180,9 +189,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def engine(self, value):
 		"""
-		This method is the setter method for **self.__engine** attribute.
+		Setter for **self.__engine** attribute.
 
-		:param value: Attribute value. ( QObject )
+		:param value: Attribute value.
+		:type value: QObject
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -192,7 +202,7 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def engine(self):
 		"""
-		This method is the deleter method for **self.__engine** attribute.
+		Deleter for **self.__engine** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -202,9 +212,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def iblSetsOutliner(self):
 		"""
-		This method is the property for **self.__iblSetsOutliner** attribute.
+		Property for **self.__iblSetsOutliner** attribute.
 
-		:return: self.__iblSetsOutliner. ( QWidget )
+		:return: self.__iblSetsOutliner.
+		:rtype: QWidget
 		"""
 
 		return self.__iblSetsOutliner
@@ -213,9 +224,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def iblSetsOutliner(self, value):
 		"""
-		This method is the setter method for **self.__iblSetsOutliner** attribute.
+		Setter for **self.__iblSetsOutliner** attribute.
 
-		:param value: Attribute value. ( QWidget )
+		:param value: Attribute value.
+		:type value: QWidget
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -225,7 +237,7 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def iblSetsOutliner(self):
 		"""
-		This method is the deleter method for **self.__iblSetsOutliner** attribute.
+		Deleter for **self.__iblSetsOutliner** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -234,9 +246,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def collectionsOutliner(self):
 		"""
-		This method is the property for **self.__collectionsOutliner** attribute.
+		Property for **self.__collectionsOutliner** attribute.
 
-		:return: self.__collectionsOutliner. ( QWidget )
+		:return: self.__collectionsOutliner.
+		:rtype: QWidget
 		"""
 
 		return self.__collectionsOutliner
@@ -245,9 +258,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def collectionsOutliner(self, value):
 		"""
-		This method is the setter method for **self.__collectionsOutliner** attribute.
+		Setter for **self.__collectionsOutliner** attribute.
 
-		:param value: Attribute value. ( QWidget )
+		:param value: Attribute value.
+		:type value: QWidget
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -257,7 +271,7 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def collectionsOutliner(self):
 		"""
-		This method is the deleter method for **self.__collectionsOutliner** attribute.
+		Deleter for **self.__collectionsOutliner** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -266,9 +280,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def view(self):
 		"""
-		This method is the property for **self.__view** attribute.
+		Property for **self.__view** attribute.
 
-		:return: self.__view. ( QWidget )
+		:return: self.__view.
+		:rtype: QWidget
 		"""
 
 		return self.__view
@@ -277,9 +292,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def view(self, value):
 		"""
-		This method is the setter method for **self.__view** attribute.
+		Setter for **self.__view** attribute.
 
-		:param value: Attribute value. ( QWidget )
+		:param value: Attribute value.
+		:type value: QWidget
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -289,7 +305,7 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def view(self):
 		"""
-		This method is the deleter method for **self.__view** attribute.
+		Deleter for **self.__view** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -298,9 +314,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@property
 	def cloudExcludedTags(self):
 		"""
-		This method is the property for **self.__cloudExcludedTags** attribute.
+		Property for **self.__cloudExcludedTags** attribute.
 
-		:return: self.__cloudExcludedTags. ( List )
+		:return: self.__cloudExcludedTags.
+		:rtype: list
 		"""
 
 		return self.__cloudExcludedTags
@@ -309,9 +326,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def cloudExcludedTags(self, value):
 		"""
-		This method is the setter method for **self.__cloudExcludedTags** attribute.
+		Setter for **self.__cloudExcludedTags** attribute.
 
-		:param value: Attribute value. ( List )
+		:param value: Attribute value.
+		:type value: list
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -321,7 +339,7 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def cloudExcludedTags(self):
 		"""
-		This method is the deleter method for **self.__cloudExcludedTags** attribute.
+		Deleter for **self.__cloudExcludedTags** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -332,10 +350,12 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 	#******************************************************************************************************************
 	def activate(self, engine):
 		"""
-		This method activates the Component.
+		Activates the Component.
 
-		:param engine: Engine to attach the Component to. ( QObject )
-		:return: Method success. ( Boolean )
+		:param engine: Engine to attach the Component to.
+		:type engine: QObject
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Activating '{0}' Component.".format(self.__class__.__name__))
@@ -350,9 +370,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def deactivate(self):
 		"""
-		This method deactivates the Component.
+		Deactivates the Component.
 
-		:return: Method success. ( Boolean )
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Deactivating '{0}' Component.".format(self.__class__.__name__))
@@ -367,9 +388,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def initializeUi(self):
 		"""
-		This method initializes the Component ui.
+		Initializes the Component ui.
 		
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Initializing '{0}' Component ui.".format(self.__class__.__name__))
@@ -413,9 +435,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def uninitializeUi(self):
 		"""
-		This method uninitializes the Component ui.
+		Uninitializes the Component ui.
 		
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Uninitializing '{0}' Component ui.".format(self.__class__.__name__))
@@ -437,9 +460,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def addWidget(self):
 		"""
-		This method adds the Component Widget to the engine.
+		Adds the Component Widget to the engine.
 
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Adding '{0}' Component Widget.".format(self.__class__.__name__))
@@ -450,9 +474,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def removeWidget(self):
 		"""
-		This method removes the Component Widget from the engine.
+		Removes the Component Widget from the engine.
 
-		:return: Method success. ( Boolean )		
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Removing '{0}' Component Widget.".format(self.__class__.__name__))
@@ -464,27 +489,30 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def __Search_Database_lineEdit__textChanged(self, text):
 		"""
-		This method is triggered when **Search_Database_lineEdit** text changes.
+		Defines the slot triggered by **Search_Database_lineEdit** Widget when text changed.
 
-		:param text: Current text value. ( QString )
+		:param text: Current text value.
+		:type text: QString
 		"""
 
 		self.setTagsCloudMatchingIblsSetsUi()
 
 	def __Case_Sensitive_Matching_pushButton__clicked(self, checked):
 		"""
-		This method is triggered when **Case_Sensitive_Matching_pushButton** Widget is clicked.
+		Defines the slot triggered by **Case_Sensitive_Matching_pushButton** Widget when clicked.
 
-		:param checked: Checked state. ( Boolean )
+		:param checked: Checked state.
+		:type checked: bool
 		"""
 
 		self.setTagsCloudMatchingIblsSetsUi()
 
 	def __Time_Low_timeEdit__timeChanged(self, time):
 		"""
-		This method is triggered when **Time_Low_timeEdit** time changes.
+		Defines the slot triggered by **Time_Low_timeEdit** Widget when time changed.
 
-		:param time: Current time. ( QTime )
+		:param time: Current time.
+		:type time: QTime
 		"""
 
 		self.Time_Low_timeEdit.time() >= self.Time_High_timeEdit.time() and \
@@ -493,9 +521,10 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def __Time_High_timeEdit__timeChanged(self, time):
 		"""
-		This method is triggered when **Time_Low_timeEdit** time changes.
+		Defines the slot triggered by **Time_Low_timeEdit** Widget when time changed.
 
-		:param time: Current time. ( QTime )
+		:param time: Current time.
+		:type time: QTime
 		"""
 
 		self.Time_High_timeEdit.time() <= self.Time_Low_timeEdit.time() and \
@@ -504,31 +533,35 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def __view__doubleClicked(self, listWidgetItem):
 		"""
-		This method is triggered when the View is double clicked.
+		Defines the slot triggered by the View when double clicked.
 
-		:param listWidgetItem: List Widget item. ( QlistWidgetItem )
+		:param listWidgetItem: List Widget item.
+		:type listWidgetItem: QlistWidgetItem
 		"""
 
 		self.Search_Database_lineEdit.setText("{0} {1}".format(self.Search_Database_lineEdit.text(), listWidgetItem.text()))
 
 	def __collectionsOutliner_view_selectionModel__selectionChanged(self, selectedItems, deselectedItems):
 		"""
-		This method is triggered when **collectionsOutliner.view** Model selection has changed.
+		Defines the slot triggered by **collectionsOutliner.view** Model when selection changed
 
-		:param selectedItems: Selected items. ( QItemSelection )
-		:param deselectedItems: Deselected items. ( QItemSelection )
+		:param selectedItems: Selected items.
+		:type selectedItems: QItemSelection
+		:param deselectedItems: Deselected items.
+		:type deselectedItems: QItemSelection
 		"""
 
 		self.setTagsCloudMatchingIblsSetsUi()
 
 	def setTagsCloudMatchingIblsSetsUi(self):
 		"""
-		This method sets the user defined pattern matching Ibl Sets and 
+		Sets the user defined pattern matching Ibl Sets and 
 		updates :mod:`sibl_gui.components.core.iblSetsOutliner.iblSetsOutliner` Component Model content.
 		
-		:return: Method success. ( Boolean )
+		:return: Method success.
+		:rtype: bool
 		
-		:note: This method may require user interaction.
+		:note: May require user interaction.
 		"""
 
 		return self.setTagsCloudMatchingIblsSets(foundations.strings.toString(self.Search_Database_lineEdit.text()),
@@ -536,24 +569,28 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def setTimeMatchingIblSetsUi(self):
 		"""
-		This method sets the user defined time matching Ibl Sets and 
+		Sets the user defined time matching Ibl Sets and 
 		updates :mod:`sibl_gui.components.core.iblSetsOutliner.iblSetsOutliner` Component Model content.
 		
-		:return: Method success. ( Boolean )
+		:return: Method success.
+		:rtype: bool
 		
-		:note: This method may require user interaction.
+		:note: May require user interaction.
 		"""
 
 		return self.setTimeMatchingIblSets(self.Time_Low_timeEdit.time(), self.Time_High_timeEdit.time())
 
 	def setTagsCloudMatchingIblsSets(self, pattern, flags=re.IGNORECASE):
 		"""
-		This method sets the pattern matching Ibl Sets and 
+		Sets the pattern matching Ibl Sets and 
 		updates :mod:`sibl_gui.components.core.iblSetsOutliner.iblSetsOutliner` Component Model content.
 
-		:param pattern: Filtering pattern. ( String )
-		:param flags: Regex filtering flags. ( Integer )
-		:return: Method success. ( Boolean )
+		:param pattern: Filtering pattern.
+		:type pattern: unicode
+		:param flags: Regex filtering flags.
+		:type flags: int
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Filtering Ibl Sets by Tags.")
@@ -579,10 +616,14 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 			if patternTokens != patternsDefault:
 				for pattern in patternTokens:
 					patternMatched = False
-					for tag in tagsCloud:
-						if re.search(pattern, tag, flags=flags):
-							patternMatched = True
-							break
+					try:
+						pattern = re.compile(pattern, flags)
+						for tag in tagsCloud:
+							if re.search(pattern, tag, flags=flags):
+								patternMatched = True
+								break
+					except re.error:
+						LOGGER.warning("!> {0} | '{1}' regex pattern is invalid!".format(self.__class__.__name__, pattern))
 					patternsMatched *= patternMatched
 
 			if patternsMatched:
@@ -603,12 +644,15 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 
 	def setTimeMatchingIblSets(self, timeLow, timeHigh):
 		"""
-		This method sets the time matching Ibl Sets and 
+		Sets the time matching Ibl Sets and 
 		updates :mod:`sibl_gui.components.core.iblSetsOutliner.iblSetsOutliner` Component Model content.
 		
-		:param timeLow: Time low. ( QTime )
-		:param timeHigh: Time high. ( QTime )
-		:return: Method success. ( Boolean )
+		:param timeLow: Time low.
+		:type timeLow: QTime
+		:param timeHigh: Time high.
+		:type timeHigh: QTime
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Filtering Ibl Sets by time range from '{0}' to '{1}'.".format(timeLow, timeHigh))
