@@ -8,7 +8,7 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines Application Database operations objects.
+	Defines Application Database operations objects.
 
 **Others:**
 
@@ -40,7 +40,7 @@ from sibl_gui.components.core.database.types import Template
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
@@ -107,19 +107,22 @@ DEFAULT_SESSION = None
 #**********************************************************************************************************************
 def createSession():
 	"""
-	This definition creates a default session.
+	Creates a default session.
 
-	:return: Database session. ( Session )
+	:return: Database session.
+	:rtype: Session
 	"""
 
 	return DEFAULT_SESSION_MAKER()
 
 def getSession(session=None):
 	"""
-	This definition returns either given session or the default one.
+	Returns either given session or the default one.
 
-	:param session: Database session. ( Session )
-	:return: Database session. ( Session )
+	:param session: Database session.
+	:type session: Session
+	:return: Database session.
+	:rtype: Session
 	"""
 
 	if session is not None:
@@ -132,11 +135,14 @@ def getSession(session=None):
 
 def query(*args, **kwargs):
 	"""
-	This definition queries given session or the default one.
+	Queries given session or the default one.
 
-	:param \*args: Arguments. ( \* )
-	:param \*\*kwargs: Keywords arguments. ( \*\* )
-	:return: Query result. ( Object )
+	:param \*args: Arguments.
+	:type \*args: \*
+	:param \*\*kwargs: Keywords arguments.
+	:type \*\*kwargs: \*\*
+	:return: Query result.
+	:rtype: object
 	"""
 
 	return getSession(kwargs.get("session")).query(*args, **kwargs)
@@ -144,10 +150,12 @@ def query(*args, **kwargs):
 @foundations.exceptions.handleExceptions(sibl_gui.components.core.database.exceptions.DatabaseOperationError)
 def commit(session=None):
 	"""
-	This definition commits changes to the Database.
+	Commits changes to the Database.
 
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	session = getSession(session)
@@ -162,11 +170,14 @@ def commit(session=None):
 
 def addItem(item, session=None):
 	"""
-	This definition adds an item to the Database.
+	Adds an item to the Database.
 
-	:param item: Item to add. ( Database object )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param item: Item to add.
+	:type item: Object
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	LOGGER.debug("> Adding: '{0}' item to the Database.".format(item))
@@ -177,14 +188,20 @@ def addItem(item, session=None):
 
 def addStandardItem(type, name, path, collection, session=None):
 	"""
-	This definition adds a new standard item to the Database.
+	Adds a new standard item to the Database.
 
-	:param type: Item type. ( Object )
-	:param name: Item name. ( String )
-	:param path: Item path. ( String )
-	:param collection: Collection id. ( String )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param type: Item type.
+	:type type: object
+	:param name: Item name.
+	:type name: unicode
+	:param path: Item path.
+	:type path: unicode
+	:param collection: Collection id.
+	:type collection: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	LOGGER.debug("> Adding: '{0}' '{1}' to the Database.".format(name, type.__name__))
@@ -192,6 +209,10 @@ def addStandardItem(type, name, path, collection, session=None):
 	session = getSession(session)
 
 	if not filterItems(query(type), "^{0}$".format(re.escape(path)), "path"):
+		if not foundations.common.pathExists(path):
+			LOGGER.warning("!> {0} | '{1}' file doesn't exists!".format(__name__, path))
+			return False
+
 		osStats = ",".join((foundations.strings.toString(stat) for stat in os.stat(path)))
 		databaseItem = type(name=name, path=path, collection=collection, osStats=osStats)
 		if databaseItem.setContent():
@@ -202,11 +223,14 @@ def addStandardItem(type, name, path, collection, session=None):
 
 def removeItem(item, session=None):
 	"""
-	This definition removes an item from the Database.
+	Removes an item from the Database.
 
-	:param item: Item to remove. ( Database object )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param item: Item to remove.
+	:type item: Object
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	LOGGER.debug("> Removing: '{0}' item from the Database.".format(item))
@@ -217,12 +241,16 @@ def removeItem(item, session=None):
 
 def removeStandardItem(type, identity, session=None):
 	"""
-	This definition removes a standard item from the Database.
+	Removes a standard item from the Database.
 
-	:param type: Item type. ( Object )
-	:param identity: Item id. ( String )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param type: Item type.
+	:type type: object
+	:param identity: Item id.
+	:type identity: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	LOGGER.debug("> Removing item type '{0}' with id '{1}' from the Database.".format(type.__name__, identity))
@@ -232,15 +260,22 @@ def removeStandardItem(type, identity, session=None):
 
 def updateItemContent(item, session=None):
 	"""
-	This definition update an item content.
+	Update an item content.
 
-	:param item: Item to set content. ( IblSet )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param item: Item to set content.
+	:type item: IblSet
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	LOGGER.debug("> Updating '{0}' '{1}' content.".format(item.name, item.__class__.__name__))
 
+	if not foundations.common.pathExists(item.path):
+		LOGGER.warning("!> {0} | '{1}' file doesn't exists!".format(__name__, item.path))
+		return False
+
 	item.osStats = ",".join(map(foundations.strings.toString, os.stat(item.path)))
 	if item.setContent():
 		return commit(getSession(session))
@@ -252,12 +287,16 @@ def updateItemContent(item, session=None):
 
 def updateItemLocation(item, path, session=None):
 	"""
-	This definition updates an item location.
+	Updates an item location.
 
-	:param item: Item to update. ( Object )
-	:param path: Item path. ( Path )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param item: Item to update.
+	:type item: object
+	:param path: Item path.
+	:type path: Path
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	LOGGER.debug("> Updating '{0}' '{1}' location.".format(item, item.__class__.__name__))
@@ -275,117 +314,154 @@ def updateItemLocation(item, path, session=None):
 
 def filterItems(items, pattern, field, flags=0):
 	"""
-	This definition filters items from the Database.
+	Filters items from the Database.
 
-	:param items: Database items. ( List )
-	:param pattern: Filtering pattern. ( String )
-	:param field: Database field to search into. ( String )
-	:param flags: Flags passed to the regex engine. ( Integer )
-	:return: Filtered items. ( List )
+	:param items: Database items.
+	:type items: list
+	:param pattern: Filtering pattern.
+	:type pattern: unicode
+	:param field: Database field to search into.
+	:type field: unicode
+	:param flags: Flags passed to the regex engine.
+	:type flags: int
+	:return: Filtered items.
+	:rtype: list
 	"""
 
 	return [item for item in items if re.search(pattern, foundations.strings.toString(item.__dict__[field]), flags)]
 
 def itemExists(items, pattern, field, flags=0):
 	"""
-	This definition returns if given item exists in the Database.
+	Returns if given item exists in the Database.
 
-	:param items: Database items. ( List )
-	:param pattern: Filtering pattern. ( String )
-	:param field: Database field to search into. ( String )
-	:param flags: Flags passed to the regex engine. ( Integer )
-	:return: Filtered items. ( List )
+	:param items: Database items.
+	:type items: list
+	:param pattern: Filtering pattern.
+	:type pattern: unicode
+	:param field: Database field to search into.
+	:type field: unicode
+	:param flags: Flags passed to the regex engine.
+	:type flags: int
+	:return: Filtered items.
+	:rtype: list
 	"""
 
 	return filterItems(items, pattern, field, flags) and True or False
 
 def getIblSets(session=None):
 	"""
-	This definition returns the Ibl Sets from the Database.
+	Returns the Ibl Sets from the Database.
 
-	:param session: Database session. ( Session )
-	:return: Database Ibl Sets. ( List )
+	:param session: Database session.
+	:type session: Session
+	:return: Database Ibl Sets.
+	:rtype: list
 	"""
 
 	return getSession(session).query(IblSet)
 
 def filterIblSets(pattern, field, flags=0, session=None):
 	"""
-	This definition filters the sets from the Database.
+	Filters the sets from the Database.
 
-	:param pattern: Filtering pattern. ( String )
-	:param field: Database field to search into. ( String )
-	:param flags: Flags passed to the regex engine. ( Integer )
-	:param session: Database session. ( Session )
-	:return: Filtered Ibl Sets. ( List )
+	:param pattern: Filtering pattern.
+	:type pattern: unicode
+	:param field: Database field to search into.
+	:type field: unicode
+	:param flags: Flags passed to the regex engine.
+	:type flags: int
+	:param session: Database session.
+	:type session: Session
+	:return: Filtered Ibl Sets.
+	:rtype: list
 	"""
 
 	return filterItems(getIblSets(getSession(session)), pattern, field, flags)
 
 def iblSetExists(path, session=None):
 	"""
-	This method returns if given Ibl Set exists in the Database.
+	Returns if given Ibl Set exists in the Database.
 
-	:param name: Ibl Set path. ( String )
-	:param session: Database session. ( Session )
-	:return: Ibl Set exists. ( Boolean )
+	:param name: Ibl Set path.
+	:type name: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Ibl Set exists.
+	:rtype: bool
 	"""
 
 	return filterIblSets("^{0}$".format(re.escape(path)), "path", session=getSession(session)) and True or False
 
 def addIblSet(name, path, collection, session=None):
 	"""
-	This definition adds a new Ibl Set to the Database.
+	Adds a new Ibl Set to the Database.
 
-	:param name: Ibl Set name. ( String )
-	:param path: Ibl Set path. ( String )
-	:param collection: Collection id. ( String )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param name: Ibl Set name.
+	:type name: unicode
+	:param path: Ibl Set path.
+	:type path: unicode
+	:param collection: Collection id.
+	:type collection: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	return addStandardItem(IblSet, name, path, collection, getSession(session))
 
 def removeIblSet(identity, session=None):
 	"""
-	This definition removes an Ibl Set from the Database.
+	Removes an Ibl Set from the Database.
 
-	:param identity: Ibl Set id. ( String )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param identity: Ibl Set id.
+	:type identity: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	return removeStandardItem(IblSet, identity, getSession(session))
 
 def updateIblSetContent(iblSet, session=None):
 	"""
-	This definition update an Ibl Set content.
+	Update an Ibl Set content.
 
-	:param iblSet: Ibl Set to set content. ( IblSet )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param iblSet: Ibl Set to set content.
+	:type iblSet: IblSet
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	return updateItemContent(iblSet, getSession(session))
 
 def updateIblSetLocation(iblSet, path, session=None):
 	"""
-	This definition updates an Ibl Set location.
+	Updates an Ibl Set location.
 
-	:param iblSet: Ibl Set to update. ( IblSet )
-	:param path: Ibl Set path. ( Path )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param iblSet: Ibl Set to update.
+	:type iblSet: IblSet
+	:param path: Ibl Set path.
+	:type path: Path
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	return updateItemLocation(iblSet, path, getSession(session))
 
 def checkIblSetsTableIntegrity(session=None):
 	"""
-	This definition checks sets table integrity.
+	Checks sets table integrity.
 
-	:param session: Database session. ( Session )
-	:return: Ibl Sets table erroneous items. ( Dictionary )
+	:param session: Database session.
+	:type session: Session
+	:return: Ibl Sets table erroneous items.
+	:rtype: dict
 	"""
 
 	LOGGER.debug("> Checking 'Sets' Database table integrity.")
@@ -422,48 +498,64 @@ def checkIblSetsTableIntegrity(session=None):
 
 def getCollections(session=None):
 	"""
-	This definition returns the Collections from the Database.
+	Returns the Collections from the Database.
 
-	:param session: Database session. ( Session )
-	:return: Database Collections. ( List )
+	:param session: Database session.
+	:type session: Session
+	:return: Database Collections.
+	:rtype: list
 	"""
 
 	return getSession(session).query(Collection)
 
 def filterCollections(pattern, field, flags=0, session=None):
 	"""
-	This definition filters the Collections from the Database.
+	Filters the Collections from the Database.
 
-	:param pattern: Filtering pattern. ( String )
-	:param field: Database field to search into. ( String )
-	:param flags: Flags passed to the regex engine. ( Integer )
-	:param session: Database session. ( Session )
-	:return: Filtered Collections. ( List )
+	:param pattern: Filtering pattern.
+	:type pattern: unicode
+	:param field: Database field to search into.
+	:type field: unicode
+	:param flags: Flags passed to the regex engine.
+	:type flags: int
+	:param session: Database session.
+	:type session: Session
+	:return: Filtered Collections.
+	:rtype: list
 	"""
 
 	return filterItems(getCollections(getSession(session)), pattern, field, flags)
 
 def getCollectionsByType(type, session=None):
 	"""
-	This method returns Collections of given type.
+	Returns Collections of given type.
 
-	:param type: Type name. ( String )
-	:param session: Database session. ( Session )
-	:return: Ibl Sets Collections. ( List )
+	:param type: Type name.
+	:type type: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Ibl Sets Collections.
+	:rtype: list
 	"""
 
 	return [collection for collection in filterCollections(type, "type", session=getSession(session))]
 
 def filterCollectionsByType(type, pattern, field, flags=0, session=None):
 	"""
-	This definition filters the Ibl Sets Collections from the Database.
+	Filters the Ibl Sets Collections from the Database.
 
-	:param type: Type name. ( String )
-	:param pattern: Filtering pattern. ( String )
-	:param field: Database field to search into. ( String )
-	:param flags: Flags passed to the regex engine. ( Integer )
-	:param session: Database session. ( Session )
-	:return: Filtered Collections. ( List )
+	:param type: Type name.
+	:type type: unicode
+	:param pattern: Filtering pattern.
+	:type pattern: unicode
+	:param field: Database field to search into.
+	:type field: unicode
+	:param flags: Flags passed to the regex engine.
+	:type flags: int
+	:param session: Database session.
+	:type session: Session
+	:return: Filtered Collections.
+	:rtype: list
 	"""
 
 	return list(set(getCollectionsByType(type, session)).intersection(
@@ -471,50 +563,68 @@ def filterCollectionsByType(type, pattern, field, flags=0, session=None):
 
 def filterIblSetsCollections(pattern, field, flags=0, session=None):
 	"""
-	This definition filters the Ibl Sets Collections from the Database.
+	Filters the Ibl Sets Collections from the Database.
 
-	:param pattern: Filtering pattern. ( String )
-	:param field: Database field to search into. ( String )
-	:param flags: Flags passed to the regex engine. ( Integer )
-	:param session: Database session. ( Session )
-	:return: Filtered Collections. ( List )
+	:param pattern: Filtering pattern.
+	:type pattern: unicode
+	:param field: Database field to search into.
+	:type field: unicode
+	:param flags: Flags passed to the regex engine.
+	:type flags: int
+	:param session: Database session.
+	:type session: Session
+	:return: Filtered Collections.
+	:rtype: list
 	"""
 
 	return filterCollectionsByType("IblSets", pattern, field, flags, getSession(session))
 
 def filterTemplatesCollections(pattern, field, flags=0, session=None):
 	"""
-	This definition filters the Templates Collections from the Database.
+	Filters the Templates Collections from the Database.
 
-	:param pattern: Filtering pattern. ( String )
-	:param field: Database field to search into. ( String )
-	:param flags: Flags passed to the regex engine. ( Integer )
-	:param session: Database session. ( Session )
-	:return: Filtered Collections. ( List )
+	:param pattern: Filtering pattern.
+	:type pattern: unicode
+	:param field: Database field to search into.
+	:type field: unicode
+	:param flags: Flags passed to the regex engine.
+	:type flags: int
+	:param session: Database session.
+	:type session: Session
+	:return: Filtered Collections.
+	:rtype: list
 	"""
 
 	return filterCollectionsByType("Templates", pattern, field, flags, getSession(session))
 
 def collectionExists(name, session=None):
 	"""
-	This method returns if the Collection exists in the Database.
+	Returns if the Collection exists in the Database.
 
-	:param name: Collection name. ( String )
-	:param session: Database session. ( Session )
-	:return: Collection exists. ( Boolean )
+	:param name: Collection name.
+	:type name: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Collection exists.
+	:rtype: bool
 	"""
 
 	return filterCollections("^{0}$".format(name), "name", session=getSession(session)) and True or False
 
 def addCollection(collection, type, comment, session=None):
 	"""
-	This definition adds a Collection to the Database.
+	Adds a Collection to the Database.
 
-	:param collection: Collection name. ( String )
-	:param type: Collection type. ( String )
-	:param comment: Collection comment. ( String )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param collection: Collection name.
+	:type collection: unicode
+	:param type: Collection type.
+	:type type: unicode
+	:param comment: Collection comment.
+	:type comment: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	LOGGER.debug("> Adding: '{0}' Collection of type '{1}' to the Database.".format(collection, type))
@@ -530,22 +640,28 @@ def addCollection(collection, type, comment, session=None):
 
 def removeCollection(identity, session=None):
 	"""
-	This definition removes a Collection from the Database.
+	Removes a Collection from the Database.
 
-	:param identity: Collection id. ( String )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param identity: Collection id.
+	:type identity: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	return removeStandardItem(Collection, identity, getSession(session))
 
 def getCollectionsIblSets(identities, session=None):
 	"""
-	This definition returns Ibl Sets from Collections ids
+	Returns Ibl Sets from Collections ids
 
-	:param identities: Collections ids. ( List )
-	:param session: Database session. ( Session )
-	:return: Ibl Sets list. ( List )
+	:param identities: Collections ids.
+	:type identities: list
+	:param session: Database session.
+	:type session: Session
+	:return: Ibl Sets list.
+	:rtype: list
 	"""
 
 	iblSets = []
@@ -558,113 +674,146 @@ def getCollectionsIblSets(identities, session=None):
 
 def getCollectionIblSetsCount(collection, session=None):
 	"""
-	This method returns given Collection Ibl Sets count.
+	Returns given Collection Ibl Sets count.
 
-	:param collection: Collection. ( Collection )
-	:param session: Database session. ( Session )
-	:return: Collection Ibl Sets count. ( Integer )
+	:param collection: Collection.
+	:type collection: Collection
+	:param session: Database session.
+	:type session: Session
+	:return: Collection Ibl Sets count.
+	:rtype: int
 	"""
 
 	return getSession(session).query(IblSet).filter_by(collection=collection.id).count()
 
 def getCollectionTemplatesCount(collection, session=None):
 	"""
-	This method returns given Collection Tempates count.
+	Returns given Collection Tempates count.
 
-	:param collection: Collection. ( Collection )
-	:param session: Database session. ( Session )
-	:return: Collection Templates count. ( Integer )
+	:param collection: Collection.
+	:type collection: Collection
+	:param session: Database session.
+	:type session: Session
+	:return: Collection Templates count.
+	:rtype: int
 	"""
 
 	return getSession(session).query(Template).filter_by(collection=collection.id).count()
 
 def getTemplates(session=None):
 	"""
-	This definition returns the Templates from the Database.
+	Returns the Templates from the Database.
 
-	:param session: Database session. ( Session )
-	:return: Database Templates. ( List )
+	:param session: Database session.
+	:type session: Session
+	:return: Database Templates.
+	:rtype: list
 	"""
 
 	return getSession(session).query(Template)
 
 def filterTemplates(pattern, field, flags=0, session=None):
 	"""
-	This definition filters the Templates from the Database.
+	Filters the Templates from the Database.
 
-	:param pattern: Filtering pattern. ( String )
-	:param field: Database field to search into. ( String )
-	:param flags: Flags passed to the regex engine. ( Integer )
-	:param session: Database session. ( Session )
-	:return: Filtered Templates. ( List )
+	:param pattern: Filtering pattern.
+	:type pattern: unicode
+	:param field: Database field to search into.
+	:type field: unicode
+	:param flags: Flags passed to the regex engine.
+	:type flags: int
+	:param session: Database session.
+	:type session: Session
+	:return: Filtered Templates.
+	:rtype: list
 	"""
 
 	return filterItems(getTemplates(getSession(session)), pattern, field, flags)
 
 def templateExists(path, session=None):
 	"""
-	This method returns if given Template exists in the Database.
+	Returns if given Template exists in the Database.
 
-	:param name: Template path. ( String )
-	:param session: Database session. ( Session )
-	:return: Template exists. ( Boolean )
+	:param name: Template path.
+	:type name: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Template exists.
+	:rtype: bool
 	"""
 
 	return filterTemplates("^{0}$".format(re.escape(path)), "path", session=getSession(session)) and True or False
 
 def addTemplate(name, path, collection, session=None):
 	"""
-	This definition adds a new Template to the Database.
+	Adds a new Template to the Database.
 
-	:param name: Template name. ( String )
-	:param path: Template path. ( String )
-	:param collection: Collection id. ( String )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param name: Template name.
+	:type name: unicode
+	:param path: Template path.
+	:type path: unicode
+	:param collection: Collection id.
+	:type collection: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	return addStandardItem(Template, name, path, collection, getSession(session))
 
 def removeTemplate(identity, session=None):
 	"""
-	This definition removes a Template from the Database.
+	Removes a Template from the Database.
 
-	:param identity: Template id. ( String )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param identity: Template id.
+	:type identity: unicode
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	return removeStandardItem(Template, identity, getSession(session))
 
 def updateTemplateContent(template, session=None):
 	"""
-	This definition update a Template content.
+	Update a Template content.
 
-	:param template: Template to Template content. ( Template )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param template: Template to Template content.
+	:type template: Template
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	return updateItemContent(template, getSession(session))
 
 def updateTemplateLocation(template, path, session=None):
 	"""
-	This definition updates a Template location.
+	Updates a Template location.
 
-	:param template: Template to update. ( Template )
-	:param path: Template path. ( Path )
-	:param session: Database session. ( Session )
-	:return: Database commit success. ( Boolean )
+	:param template: Template to update.
+	:type template: Template
+	:param path: Template path.
+	:type path: Path
+	:param session: Database session.
+	:type session: Session
+	:return: Database commit success.
+	:rtype: bool
 	"""
 
 	return updateItemLocation(template, path, getSession(session))
 
 def checkTemplatesTableIntegrity(session=None):
 	"""
-	This definition checks Templates table integrity.
+	Checks Templates table integrity.
 
-	:param session: Database session. ( Session )
-	:return: Templates table erroneous items. ( Dictionary )
+	:param session: Database session.
+	:type session: Session
+	:return: Templates table erroneous items.
+	:rtype: dict
 	"""
 
 	LOGGER.debug("> Checking 'Templates' Database table integrity.")
