@@ -8,7 +8,7 @@
 	Windows, Linux, Mac Os X.
 
 **Description:**
-	This module defines the Application caches classes.
+	Defines the Application caches classes.
 
 **Others:**
 
@@ -39,7 +39,7 @@ from umbra.globals.uiConstants import UiConstants
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
@@ -57,14 +57,15 @@ LOGGER = foundations.verbose.installLogger()
 #**********************************************************************************************************************
 class CacheMetrics(foundations.dataStructures.Structure):
 	"""
-	This class represents a storage object for cache metrics.
+	Defines a storage object for cache metrics.
 	"""
 
 	def __init__(self, **kwargs):
 		"""
-		This method initializes the class.
+		Initializes the class.
 
-		:param kwargs: type, content. ( Key / Value pairs )
+		:param kwargs: type, content.
+		:type kwargs: dict
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
@@ -73,7 +74,7 @@ class CacheMetrics(foundations.dataStructures.Structure):
 
 class AbstractResourcesCache(QObject):
 	"""
-	This class is a `QObject <http://doc.qt.nokia.com/qobject.html>`_ subclass used as an abstract resources cache.
+	Defines a `QObject <http://doc.qt.nokia.com/qobject.html>`_ subclass used as an abstract resources cache.
 	"""
 
 	contentAdded = pyqtSignal(list)
@@ -81,7 +82,8 @@ class AbstractResourcesCache(QObject):
 	This signal is emited by the :class:`AsynchronousGraphicsItemsCache` class
 	whenever content has been added. ( pyqtSignal )
 	
-	:return: Content added to the cache. ( List )	
+	:return: Content added to the cache.
+	:rtype: list
 	"""
 
 	contentRemoved = pyqtSignal(list)
@@ -89,14 +91,16 @@ class AbstractResourcesCache(QObject):
 	This signal is emited by the :class:`AsynchronousGraphicsItemsCache` class
 	whenever content has been removed. ( pyqtSignal )
 	
-	:return: Content removed from the cache. ( List )	
+	:return: Content removed from the cache.
+	:rtype: list
 	"""
 
 	def __init__(self, parent=None):
 		"""
-		This method initializes the class.
+		Initializes the class.
 
-		:param parent: Object parent. ( QObject )
+		:param parent: Object parent.
+		:type parent: QObject
 		"""
 
 		QObject.__init__(self, parent)
@@ -109,9 +113,10 @@ class AbstractResourcesCache(QObject):
 	@property
 	def mapping(self):
 		"""
-		This method is the property for **self.__mapping** attribute.
+		Property for **self.__mapping** attribute.
 
-		:return: self.__mapping. ( Dictionary )
+		:return: self.__mapping.
+		:rtype: dict
 		"""
 
 		return self.__mapping
@@ -120,9 +125,10 @@ class AbstractResourcesCache(QObject):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def mapping(self, value):
 		"""
-		This method is the setter method for **self.__mapping** attribute.
+		Setter for **self.__mapping** attribute.
 
-		:param value: Attribute value. ( Dictionary )
+		:param value: Attribute value.
+		:type value: dict
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -132,7 +138,7 @@ class AbstractResourcesCache(QObject):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def mapping(self):
 		"""
-		This method is the deleter method for **self.__mapping** attribute.
+		Deleter for **self.__mapping** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -143,77 +149,90 @@ class AbstractResourcesCache(QObject):
 	#******************************************************************************************************************
 	def __getitem__(self, item):
 		"""
-		This method reimplements the :meth:`object.__getitem__` method.
+		Reimplements the :meth:`object.__getitem__` method.
 
-		:param item: Item name. ( String )
-		:return: Item. ( Object )
+		:param item: Item name.
+		:type item: unicode
+		:return: Item.
+		:rtype: object
 		"""
 
 		return self.__mapping.__getitem__(item)
 
 	def __setitem__(self, key, value):
 		"""
-		This method reimplements the :meth:`object.__setitem__` method.
+		Reimplements the :meth:`object.__setitem__` method.
 
-		:param key: Key. ( String )
-		:param value: Item. ( Object )
+		:param key: Key.
+		:type key: unicode
+		:param value: Value.
+		:type value: object
 		"""
 
 		self.__mapping.__setitem__(key, value)
 
 	def __iter__(self):
 		"""
-		This method reimplements the :meth:`object.__iter__` method.
+		Reimplements the :meth:`object.__iter__` method.
 
-		:return: Paths iterator. ( Object )
+		:return: Paths iterator.
+		:rtype: object
 		"""
 
 		return self.__mapping.iteritems()
 
 	def __contains__(self, item):
 		"""
-		This method reimplements the :meth:`object.__contains__` method.
+		Reimplements the :meth:`object.__contains__` method.
 
-		:param item: Item name. ( String )
-		:return: Item existence. ( Boolean )
+		:param item: Item name.
+		:type item: unicode
+		:return: Item existence.
+		:rtype: bool
 		"""
 
 		return item in self.__mapping.keys()
 
 	def __len__(self):
 		"""
-		This method reimplements the :meth:`object.__len__` method.
+		Reimplements the :meth:`object.__len__` method.
 
-		:return: Paths count. ( Integer )
+		:return: Paths count.
+		:rtype: int
 		"""
 
 		return len(self.__mapping.keys())
 
 	def isCached(self, key):
 		"""
-		This method returns if given content is cached.
+		Returns if given content is cached.
 
-		:param key: Content to retrieve. ( Object )
-		:return: Is content cached. ( Boolean )
+		:param key: Content to retrieve.
+		:type key: object
+		:return: Is content cached.
+		:rtype: bool
 		"""
 
 		return key in self
 
 	def listContent(self):
 		"""
-		This method lists the cache content.
+		Lists the cache content.
 
-		:return: Cache content. ( List )
+		:return: Cache content.
+		:rtype: list
 		"""
 
 		return self.__mapping.keys()
 
 	def addContent(self, **content):
 		"""
-		This method adds given content to the cache.
+		Adds given content to the cache.
 
-		:param \*\*content: Content to add. ( \*\* )
-		:return: Method success. ( Boolean )
+		:param \*\*content: Content to add.
+		:type \*\*content: \*\*
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Adding '{0}' content to the cache.".format(self.__class__.__name__, content))
@@ -224,10 +243,12 @@ class AbstractResourcesCache(QObject):
 
 	def removeContent(self, *keys):
 		"""
-		This method removes given content from the cache.
+		Removes given content from the cache.
 
-		:param \*keys: Content to remove. ( \* )
-		:return: Method success. ( Boolean )
+		:param \*keys: Content to remove.
+		:type \*keys: \*
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Removing '{0}' content from the cache.".format(self.__class__.__name__, keys))
@@ -242,10 +263,12 @@ class AbstractResourcesCache(QObject):
 
 	def getContent(self, key):
 		"""
-		This method gets given content from the cache.
+		Gets given content from the cache.
 
-		:param key: Content to retrieve. ( Object )
-		:return: Content. ( Object )
+		:param key: Content to retrieve.
+		:type key: object
+		:return: Content.
+		:rtype: object
 		"""
 
 		LOGGER.debug("> Retrieving '{0}' content from the cache.".format(self.__class__.__name__, key))
@@ -254,9 +277,10 @@ class AbstractResourcesCache(QObject):
 
 	def flushContent(self):
 		"""
-		This method flushes the cache content.
+		Flushes the cache content.
 
-		:return: Method success. ( Boolean )
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Flushing cache content.".format(self.__class__.__name__))
@@ -268,9 +292,10 @@ class AbstractResourcesCache(QObject):
 
 	def getMetrics(self):
 		"""
-		This method returns the cache metrics.
+		Returns the cache metrics.
 
-		:return: Cache metrics. ( Dictionary )
+		:return: Cache metrics.
+		:rtype: dict
 		"""
 
 		cacheMetrics = CacheMetrics()
@@ -280,16 +305,19 @@ class AbstractResourcesCache(QObject):
 
 class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	"""
-	This class provides an asynchronous graphics items cache.
+	Defines an asynchronous graphics items cache.
 	"""
 
 	def __init__(self, parent=None, type=None, placeholder=None):
 		"""
-		This method initializes the class.
+		Initializes the class.
 		
-		:param parent: Object parent. ( QObject )
-		:param type: Cache type. ( QImage / QPixmap / QIcon )
-		:param placeholder: Placeholder image. ( String )
+		:param parent: Object parent.
+		:type parent: QObject
+		:param type: Cache type.
+		:type type: QImage or QPixmap or QIcon
+		:param placeholder: Placeholder image.
+		:type placeholder: unicode
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
@@ -313,9 +341,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@property
 	def type(self):
 		"""
-		This method is the property for **self.__type** attribute.
+		Property for **self.__type** attribute.
 
-		:return: self.__type. ( QObject )
+		:return: self.__type.
+		:rtype: QObject
 		"""
 
 		return self.__type
@@ -324,9 +353,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def type(self, value):
 		"""
-		This method is the setter method for **self.__type** attribute.
+		Setter for **self.__type** attribute.
 
-		:param value: Attribute value. ( QObject )
+		:param value: Attribute value.
+		:type value: QObject
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -336,7 +366,7 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def type(self):
 		"""
-		This method is the deleter method for **self.__type** attribute.
+		Deleter for **self.__type** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -345,9 +375,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@property
 	def placeholder(self):
 		"""
-		This method is the property for **self.__placeholder** attribute.
+		Property for **self.__placeholder** attribute.
 
-		:return: self.__placeholder. ( String )
+		:return: self.__placeholder.
+		:rtype: unicode
 		"""
 
 		return self.__placeholder
@@ -356,9 +387,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def placeholder(self, value):
 		"""
-		This method is the setter method for **self.__placeholder** attribute.
+		Setter for **self.__placeholder** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value.
+		:type value: unicode
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -368,7 +400,7 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def placeholder(self):
 		"""
-		This method is the deleter method for **self.__placeholder** attribute.
+		Deleter for **self.__placeholder** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -377,9 +409,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@property
 	def placeholderGraphicsItem(self):
 		"""
-		This method is the property for **self.__placeholderGraphicsItem** attribute.
+		Property for **self.__placeholderGraphicsItem** attribute.
 
-		:return: self.__placeholderGraphicsItem. ( QObject )
+		:return: self.__placeholderGraphicsItem.
+		:rtype: QObject
 		"""
 
 		return self.__placeholderGraphicsItem
@@ -388,9 +421,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def placeholderGraphicsItem(self, value):
 		"""
-		This method is the setter method for **self.__placeholderGraphicsItem** attribute.
+		Setter for **self.__placeholderGraphicsItem** attribute.
 
-		:param value: Attribute value. ( QObject )
+		:param value: Attribute value.
+		:type value: QObject
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -400,7 +434,7 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def placeholderGraphicsItem(self):
 		"""
-		This method is the deleter method for **self.__placeholderGraphicsItem** attribute.
+		Deleter for **self.__placeholderGraphicsItem** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -409,9 +443,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@property
 	def worker(self):
 		"""
-		This method is the property for **self.__worker** attribute.
+		Property for **self.__worker** attribute.
 
-		:return: self.__worker. ( QThread )
+		:return: self.__worker.
+		:rtype: QThread
 		"""
 
 		return self.__worker
@@ -420,9 +455,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@foundations.exceptions.handleExceptions(AssertionError)
 	def worker(self, value):
 		"""
-		This method is the setter method for **self.__worker** attribute.
+		Setter for **self.__worker** attribute.
 
-		:param value: Attribute value. ( QThread )
+		:param value: Attribute value.
+		:type value: QThread
 		"""
 
 		if value is not None:
@@ -435,7 +471,7 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def worker(self):
 		"""
-		This method is the deleter method for **self.__worker** attribute.
+		Deleter for **self.__worker** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -446,10 +482,12 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	#******************************************************************************************************************
 	def __worker__imageLoaded(self, image, size):
 		"""
-		This method is triggered by the :obj:`AsynchronousGraphicsItemsCache.worker` method when an image has been loaded.
+		Defines the slot triggered by :obj:`AsynchronousGraphicsItemsCache.worker` method when an image has been loaded.
 		
-		:param image: Loaded image. ( QImage )
-		:param size: Image size. ( String )
+		:param image: Loaded image.
+		:type image: QImage
+		:param size: Image size.
+		:type size: unicode
 		"""
 
 		graphicsItem = sibl_gui.ui.common.convertImage(image, self.__type)
@@ -463,9 +501,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 
 	def __setPlaceholderGraphicsItem(self, path):
 		"""
-		This method sets the placeholderGraphicsItem graphics item.
+		Sets the placeholderGraphicsItem graphics item.
 		
-		:param path: Placeholder image path. ( String )
+		:param path: Placeholder image path.
+		:type path: unicode
 		"""
 
 		if not foundations.common.pathExists(path):
@@ -479,11 +518,14 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 
 	def getContent(self, key, size="Default"):
 		"""
-		This method reimplements the :meth:`AbstractResourcesCache.getContent` method.
+		Reimplements the :meth:`AbstractResourcesCache.getContent` method.
 
-		:param key: Content to retrieve. ( Object )
-		:param size: Size to retrieve. ( String )
-		:return: Content. ( Object )
+		:param key: Content to retrieve.
+		:type key: object
+		:param size: Size to retrieve.
+		:type size: unicode
+		:return: Content.
+		:rtype: object
 		"""
 
 		LOGGER.debug("> Retrieving '{0}' content from the cache.".format(self.__class__.__name__, key))
@@ -494,9 +536,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 
 	def flushContent(self):
 		"""
-		This method reimplements the :meth:`AbstractResourcesCache.flushContent` method.
+		Reimplements the :meth:`AbstractResourcesCache.flushContent` method.
 
-		:return: Method success. ( Boolean )
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Flushing cache content.".format(self.__class__.__name__))
@@ -510,10 +553,12 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 
 	def loadContent(self, **content):
 		"""
-		This method loads given content into the cache.
+		Loads given content into the cache.
 		
-		:param \*\*content: Content to add. ( \*\* )
-		:return: Method success. ( Boolean )
+		:param \*\*content: Content to add.
+		:type \*\*content: \*\*
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Adding '{0}' content to the cache.".format(self.__class__.__name__, content))
@@ -539,10 +584,12 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 	@foundations.exceptions.handleExceptions(foundations.exceptions.FileExistsError)
 	def loadAsynchronousContent(self, **content):
 		"""
-		This method loads given content asynchronously into the cache.
+		Loads given content asynchronously into the cache.
 
-		:param \*\*content: Content to add. ( \*\* )
-		:return: Method success. ( Boolean )
+		:param \*\*content: Content to add.
+		:type \*\*content: \*\*
+		:return: Method success.
+		:rtype: bool
 		"""
 
 		LOGGER.debug("> Adding '{0}' content to the cache.".format(self.__class__.__name__, content))
@@ -580,9 +627,10 @@ class AsynchronousGraphicsItemsCache(AbstractResourcesCache):
 
 	def getMetrics(self):
 		"""
-		This method reimplements the :meth:`AbstractResourcesCache.getMetrics` method.
+		Reimplements the :meth:`AbstractResourcesCache.getMetrics` method.
 
-		:return: Cache metrics. ( Dictionary )
+		:return: Cache metrics.
+		:rtype: dict
 		"""
 
 		cacheMetrics = AbstractResourcesCache.getMetrics(self)
