@@ -1,22 +1,22 @@
-#/usr/bin/bash
+#!/usr/bin/env bash
 echo -------------------------------------------------------------------------------
 echo sIBL_GUI - Windows - Overall Build
 echo -------------------------------------------------------------------------------
 
-export PYINSTALLER=c:/pyinstaller
+export PYINSTALLER_DIRECTORY=c:/pyinstaller
 export PYTHONPATH=$PROJECT
 
-export PROJECT=z:/Documents/Development/sIBL_GUI
-export MAJOR_VERSION=4
+export PROJECT_DIRECTORY=z:/Documents/Development/sIBL_GUI
+export PROJECT_MAJOR_VERSION=4
 
-export UTILITIES=$PROJECT/utilities
+export UTILITIES_DIRECTORY=$PROJECT_DIRECTORY/utilities
 
-export SOURCE=$PROJECT
-export RELEASES=$PROJECT/releases/Windows
-export DISTRIBUTION=$RELEASES/dist
-export BUILD=$RELEASES/build
-export BUNDLE=$RELEASES/sIBL_GUI\ $MAJOR_VERSION
-export DEPENDENCIES=$BUNDLE
+export SOURCE_DIRECTORY=$PROJECT_DIRECTORY
+export RELEASES_DIRECTORY=$PROJECT_DIRECTORY/releases/Windows
+export DISTRIBUTION_DIRECTORY=$RELEASES_DIRECTORY/dist
+export BUILD_DIRECTORY=$RELEASES_DIRECTORY/build
+export BUNDLE_DIRECTORY=$RELEASES_DIRECTORY/sIBL_GUI\ $PROJECT_MAJOR_VERSION
+export DEPENDENCIES_DIRECTORY=$BUNDLE_DIRECTORY
 
 IFS=","
 
@@ -24,13 +24,14 @@ IFS=","
 echo -------------------------------------------------------------------------------
 echo Cleanup - Begin
 echo -------------------------------------------------------------------------------
-rm -rf $BUILD $DISTRIBUTION $DEPENDENCIES $BUNDLE
+rm -rf $BUILD_DIRECTORY $DISTRIBUTION_DIRECTORY $DEPENDENCIES_DIRECTORY $BUNDLE_DIRECTORY
 packages="foundations,manager,umbra,sibl_gui"
+types=".pyc,.pyo,.DS_Store,Thumbs.db"
 for package in $packages
 do
-	for type in ".pyc,.pyo,.DS_Store,Thumbs.db"
+	for type in $types
 	do
-		python $UTILITIES/recursiveRemove.py $( $UTILITIES/getPackagePath.py $package ) $type
+		python $UTILITIES_DIRECTORY/recursiveRemove.py --input $( $UTILITIES_DIRECTORY/getPackagePath.py --package $package ) --pattern $type
 	done
 done
 echo -------------------------------------------------------------------------------
@@ -42,8 +43,8 @@ echo ---------------------------------------------------------------------------
 echo Build - Begin
 echo -------------------------------------------------------------------------------
 #! python $PYINSTALLER/Makespec.py --noconsole --icon "$SOURCE/sibl_gui/resources/images/Icon_Light.ico" $SOURCE/sIBL_GUI.py -o $RELEASES
-cp $UTILITIES/windowsSetup.py $RELEASES/sIBL_GUI.spec
-python $PYINSTALLER/Build.py $RELEASES/sIBL_GUI.spec
+cp $UTILITIES_DIRECTORY/windowsSetup.py $RELEASES_DIRECTORY/sIBL_GUI.spec
+python $PYINSTALLER_DIRECTORY/Build.py $RELEASES_DIRECTORY/sIBL_GUI.spec
 echo -------------------------------------------------------------------------------
 echo Build - End
 echo -------------------------------------------------------------------------------
@@ -52,25 +53,25 @@ echo ---------------------------------------------------------------------------
 echo -------------------------------------------------------------------------------
 echo Release - Begin
 echo -------------------------------------------------------------------------------
-cp -r $DISTRIBUTION/sIBL_GUI $BUNDLE
+cp -r $DISTRIBUTION_DIRECTORY/sIBL_GUI $BUNDLE_DIRECTORY
 for package in $packages
 do
-	cp -rL $( cygpath --unix $( $UTILITIES/getPackagePath.py $package ) ) $DEPENDENCIES/$package
+	cp -rL $( cygpath --unix $( $UTILITIES_DIRECTORY/getPackagePath.py --package $package ) ) $DEPENDENCIES_DIRECTORY/$package
 done
 packages="umbra,sibl_gui"
 extensions="bmp,icns,ico"
 for package in $packages
 do
-	rm -rf $DEPENDENCIES/$package/resources/images/builders
+	rm -rf $DEPENDENCIES_DIRECTORY/$package/resources/images/builders
 
 	for extension in $extensions
 	do
-		rm -f $DEPENDENCIES/$package/resources/images/*.$extension
+		rm -f $DEPENDENCIES_DIRECTORY/$package/resources/images/*.$extension
 	done
 done
-rm -f $DEPENDENCIES/sibl_gui/libraries/freeImage/resources/*.dylib
-rm -f $DEPENDENCIES/sibl_gui/libraries/freeImage/resources/*.so
-rm -rf $DEPENDENCIES/*/tests
+rm -f $DEPENDENCIES_DIRECTORY/sibl_gui/libraries/freeImage/resources/*.dylib
+rm -f $DEPENDENCIES_DIRECTORY/sibl_gui/libraries/freeImage/resources/*.so
+rm -rf $DEPENDENCIES_DIRECTORY/*/tests
 echo -------------------------------------------------------------------------------
 echo Release - End
 echo -------------------------------------------------------------------------------
@@ -78,7 +79,7 @@ echo ---------------------------------------------------------------------------
 echo -------------------------------------------------------------------------------
 echo Templates Textile Files Cleanup - Begin
 echo -------------------------------------------------------------------------------
-python $UTILITIES/recursiveRemove.py $DEPENDENCIES/sibl_gui/resources/templates/ .rst
+python $UTILITIES_DIRECTORY/recursiveRemove.py --input $DEPENDENCIES_DIRECTORY/sibl_gui/resources/templates/ --pattern .rst
 echo -------------------------------------------------------------------------------
 echo Templates Textile Files Cleanup - End
 echo -------------------------------------------------------------------------------
@@ -86,11 +87,11 @@ echo ---------------------------------------------------------------------------
 echo -------------------------------------------------------------------------------
 echo Console Build - Begin
 echo -------------------------------------------------------------------------------
-rm -rf $BUILD $DISTRIBUTION
+rm -rf $BUILD_DIRECTORY $DISTRIBUTION_DIRECTORY
 export CONSOLE_BUILD=True
-python $PYINSTALLER/Build.py $RELEASES/sIBL_GUI.spec
-cp -r $DISTRIBUTION/sIBL_GUI/sIBL_GUI.exe $BUNDLE/sIBL_GUI\ $MAJOR_VERSION\ -\ Console.exe
-cp -r $DISTRIBUTION/sIBL_GUI/sIBL_GUI.exe.manifest $BUNDLE/sIBL_GUI\ $MAJOR_VERSION\ -\ Console.exe.manifest
+python $PYINSTALLER_DIRECTORY/Build.py $RELEASES_DIRECTORY/sIBL_GUI.spec
+cp -r $DISTRIBUTION_DIRECTORY/sIBL_GUI/sIBL_GUI.exe $BUNDLE_DIRECTORY/sIBL_GUI\ $PROJECT_MAJOR_VERSION\ -\ Console.exe
+cp -r $DISTRIBUTION_DIRECTORY/sIBL_GUI/sIBL_GUI.exe.manifest $BUNDLE_DIRECTORY/sIBL_GUI\ $PROJECT_MAJOR_VERSION\ -\ Console.exe.manifest
 echo -------------------------------------------------------------------------------
 echo Console Build - End
 echo -------------------------------------------------------------------------------
